@@ -16,7 +16,7 @@ the journal.
 """
 
 import logging
-from typing import Any, Callable, Dict, Optional
+from typing import Any, Callable, Dict, Iterable, Iterator, Optional, Tuple, Union
 
 from swh.core.db import BaseDb
 from swh.model.model import (
@@ -84,7 +84,12 @@ COLUMNS = {
     "metadata_authority": ["type", "url"],
     "metadata_fetcher": ["name", "version"],
     "origin": ["url"],
-    "origin_visit": ["visit", "type", ("origin.url", "origin"), "date",],
+    "origin_visit": [
+        "visit",
+        "type",
+        ("origin.url", "origin"),
+        "date",
+    ],
     "origin_visit_status": [
         ("origin_visit_status.visit", "visit"),
         ("origin.url", "origin"),
@@ -115,12 +120,8 @@ COLUMNS = {
     "revision": [
         ("revision.id", "id"),
         "date",
-        "date_offset",
-        "date_neg_utc_offset",
         "date_offset_bytes",
         "committer_date",
-        "committer_date_offset",
-        "committer_date_neg_utc_offset",
         "committer_date_offset_bytes",
         "type",
         "directory",
@@ -146,8 +147,6 @@ COLUMNS = {
     "release": [
         ("release.id", "id"),
         "date",
-        "date_offset",
-        "date_neg_utc_offset",
         "date_offset_bytes",
         "comment",
         ("release.name", "name"),
@@ -171,7 +170,9 @@ JOINS = {
         "person c on revision.committer=c.id",
     ],
     "origin_visit": ["origin on origin_visit.origin=origin.id"],
-    "origin_visit_status": ["origin on origin_visit_status.origin=origin.id",],
+    "origin_visit_status": [
+        "origin on origin_visit_status.origin=origin.id",
+    ],
     "raw_extrinsic_metadata": [
         "metadata_authority on "
         "raw_extrinsic_metadata.authority_id=metadata_authority.id",
@@ -187,7 +188,7 @@ EXTRA_WHERE = {
 
 def directory_converter(db: BaseDb, directory_d: Dict[str, Any]) -> Directory:
     """Convert directory from the flat representation to swh model
-       compatible objects.
+    compatible objects.
 
     """
     columns = ["target", "name", "perms"]
@@ -220,14 +221,18 @@ def directory_converter(db: BaseDb, directory_d: Dict[str, Any]) -> Directory:
                 )
                 entries.append(entry)
 
-    return Directory(id=directory_d["id"], entries=tuple(entries),)
+    return Directory(
+        id=directory_d["id"],
+        entries=tuple(entries),
+        raw_manifest=directory_d["raw_manifest"],
+    )
 
 
 def raw_extrinsic_metadata_converter(
     db: BaseDb, metadata: Dict[str, Any]
 ) -> RawExtrinsicMetadata:
     """Convert a raw extrinsic metadata from the flat representation to swh model
-       compatible objects.
+    compatible objects.
 
     """
     return db_to_raw_extrinsic_metadata(metadata)
@@ -235,7 +240,7 @@ def raw_extrinsic_metadata_converter(
 
 def extid_converter(db: BaseDb, extid: Dict[str, Any]) -> ExtID:
     """Convert an extid from the flat representation to swh model
-       compatible objects.
+    compatible objects.
 
     """
     return db_to_extid(extid)
@@ -243,7 +248,7 @@ def extid_converter(db: BaseDb, extid: Dict[str, Any]) -> ExtID:
 
 def revision_converter(db: BaseDb, revision_d: Dict[str, Any]) -> Revision:
     """Convert revision from the flat representation to swh model
-       compatible objects.
+    compatible objects.
 
     """
     revision = db_to_revision(revision_d)
@@ -253,7 +258,7 @@ def revision_converter(db: BaseDb, revision_d: Dict[str, Any]) -> Revision:
 
 def release_converter(db: BaseDb, release_d: Dict[str, Any]) -> Release:
     """Convert release from the flat representation to swh model
-       compatible objects.
+    compatible objects.
 
     """
     release = db_to_release(release_d)
@@ -263,7 +268,7 @@ def release_converter(db: BaseDb, release_d: Dict[str, Any]) -> Release:
 
 def snapshot_converter(db: BaseDb, snapshot_d: Dict[str, Any]) -> Snapshot:
     """Convert snapshot from the flat representation to swh model
-       compatible objects.
+    compatible objects.
 
     """
     columns = ["name", "target", "target_type"]
@@ -289,7 +294,10 @@ def snapshot_converter(db: BaseDb, snapshot_d: Dict[str, Any]) -> Snapshot:
                 branch = None
             branches[name] = branch
 
-    return Snapshot(id=snapshot_d["id"], branches=branches,)
+    return Snapshot(
+        id=snapshot_d["id"],
+        branches=branches,
+    )
 
 
 CONVERTERS: Dict[str, Callable[[BaseDb, Dict[str, Any]], BaseModel]] = {
@@ -326,15 +334,17 @@ def object_to_offset(object_id, numbits):
     return int.from_bytes(truncated_id_bytes, byteorder="big") >> shift_bits
 
 
-def byte_ranges(numbits, start_object=None, end_object=None):
+def byte_ranges(
+    numbits: int, start_object: Optional[str] = None, end_object: Optional[str] = None
+) -> Iterator[Tuple[Optional[bytes], Optional[bytes]]]:
     """Generate start/end pairs of bytes spanning numbits bits and
        constrained by optional start_object and end_object.
 
     Args:
-        numbits (int): Number of bits in which we divide input space
-        start_object (str): Hex object id contained in the first range
+        numbits: Number of bits in which we divide input space
+        start_object: Hex object id contained in the first range
                             returned
-        end_object (str): Hex object id contained in the last range
+        end_object: Hex object id contained in the last range
                           returned
 
     Yields:
@@ -367,7 +377,9 @@ def byte_ranges(numbits, start_object=None, end_object=None):
             yield to_bytes(start), to_bytes(end)
 
 
-def raw_extrinsic_metadata_target_ranges(start_object=None, end_object=None):
+def raw_extrinsic_metadata_target_ranges(
+    start_object: Optional[str] = None, end_object: Optional[str] = None
+) -> Iterator[Tuple[Optional[str], Optional[str]]]:
     """Generate ranges of values for the `target` attribute of `raw_extrinsic_metadata`
     objects.
 
@@ -442,17 +454,26 @@ def raw_extrinsic_metadata_target_ranges(start_object=None, end_object=None):
     yield start_swhid, end_object
 
 
-def integer_ranges(start, end, block_size=1000):
-    for start in range(start, end, block_size):
-        if start == 0:
+def integer_ranges(
+    start: str, end: str, block_size: int = 1000
+) -> Iterator[Tuple[Optional[int], Optional[int]]]:
+    for range_start in range(int(start), int(end), block_size):
+        if range_start == 0:
             yield None, block_size
-        elif start + block_size > end:
-            yield start, end
+        elif range_start + block_size > int(end):
+            yield range_start, int(end)
         else:
-            yield start, start + block_size
+            yield range_start, range_start + block_size
 
 
-RANGE_GENERATORS = {
+RANGE_GENERATORS: Dict[
+    str,
+    Union[
+        Callable[[str, str], Iterable[Tuple[Optional[str], Optional[str]]]],
+        Callable[[str, str], Iterable[Tuple[Optional[bytes], Optional[bytes]]]],
+        Callable[[str, str], Iterable[Tuple[Optional[int], Optional[int]]]],
+    ],
+] = {
     "content": lambda start, end: byte_ranges(24, start, end),
     "skipped_content": lambda start, end: [(None, None)],
     "directory": lambda start, end: byte_ranges(24, start, end),
@@ -564,9 +585,9 @@ MANDATORY_KEYS = ["storage", "journal_writer"]
 
 class JournalBackfiller:
     """Class in charge of reading the storage's objects and sends those
-       back to the journal's topics.
+    back to the journal's topics.
 
-       This is designed to be run periodically.
+    This is designed to be run periodically.
 
     """
 
@@ -614,20 +635,14 @@ class JournalBackfiller:
             )
 
         if object_type in ["origin", "origin_visit", "origin_visit_status"]:
-            if start_object:
-                start_object = int(start_object)
-            else:
-                start_object = 0
-            if end_object:
-                end_object = int(end_object)
-            else:
-                end_object = 100 * 1000 * 1000  # hard-coded limit
+            start_object = start_object or "0"
+            end_object = end_object or str(100_000_000)  # hard-coded limit
 
         return start_object, end_object
 
     def run(self, object_type, start_object, end_object, dry_run=False):
         """Reads storage's subscribed object types and send them to the
-           journal's reading topic.
+        journal's reading topic.
 
         """
         start_object, end_object = self.parse_arguments(
