@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2020  The Software Heritage developers
+# Copyright (C) 2019-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -198,11 +198,13 @@ def _prepared_exists_statement(
 ]:
     """Shorthand for using `_prepared_statement` for queries that only
     check which ids in a list exist in the table."""
-    return _prepared_statement(f"SELECT id FROM {table_name} WHERE id IN ?")
+    return _prepared_statement(f"SELECT id FROM {table_name} WHERE id = ?")
 
 
 def _prepared_select_statement(
-    row_class: Type[BaseRow], clauses: str = "", cols: Optional[List[str]] = None,
+    row_class: Type[BaseRow],
+    clauses: str = "",
+    cols: Optional[List[str]] = None,
 ) -> Callable[[Callable[..., TRet]], Callable[..., TRet]]:
     if cols is None:
         cols = row_class.cols()
@@ -213,7 +215,8 @@ def _prepared_select_statement(
 
 
 def _prepared_select_statements(
-    row_class: Type[BaseRow], queries: Dict[Any, str],
+    row_class: Type[BaseRow],
+    queries: Dict[Any, str],
 ) -> Callable[[Callable[..., TRet]], Callable[..., TRet]]:
     """Like _prepared_statement, but supports multiple statements, passed a dict,
     and passes a dict of prepared statements to the decorated method"""
@@ -298,7 +301,7 @@ class CqlRunner:
         retry=retry_if_exception_type(CoordinationFailure),
     )
     def _execute_many_with_retries(
-        self, statement, args_list: List[Tuple]
+        self, statement, args_list: Sequence[Tuple]
     ) -> Iterable[Dict[str, Any]]:
         for res in execute_concurrent_with_args(self._session, statement, args_list):
             yield from res.result_or_exc
@@ -331,11 +334,15 @@ class CqlRunner:
         else:
             return None
 
-    def _missing(self, statement, ids):
+    def _missing(self, statement: PreparedStatement, ids):
         found_ids = set()
-        for id_group in grouper(ids, PARTITION_KEY_RESTRICTION_MAX_SIZE):
-            rows = self._execute_with_retries(statement, [list(id_group)])
-            found_ids.update(row["id"] for row in rows)
+
+        if not ids:
+            return []
+
+        for row in self._execute_many_with_retries(statement, [(id_,) for id_ in ids]):
+            found_ids.add(row["id"])
+
         return [id_ for id_ in ids if id_ not in found_ids]
 
     ##########################
@@ -390,7 +397,7 @@ class CqlRunner:
         else:
             return None
 
-    def content_missing_from_hashes(
+    def content_missing_from_all_hashes(
         self, contents_hashes: List[Dict[str, bytes]]
     ) -> Iterator[Dict[str, bytes]]:
         for group in grouper(contents_hashes, PARTITION_KEY_RESTRICTION_MAX_SIZE):
@@ -406,7 +413,7 @@ class CqlRunner:
             for content in group:
                 for algo in HASH_ALGORITHMS:
                     assert content.get(algo) is not None, (
-                        "content_missing_from_hashes must not be called with "
+                        "content_missing_from_all_hashes must not be called with "
                         "partial hashes."
                     )
                 if tuple(content[algo] for algo in HASH_ALGORITHMS) not in present:
@@ -652,7 +659,9 @@ class CqlRunner:
         self._add_one(statement, release)
 
     @_prepared_select_statement(ReleaseRow, "WHERE id in ?")
-    def release_get(self, release_ids: List[str], *, statement) -> Iterable[ReleaseRow]:
+    def release_get(
+        self, release_ids: List[Sha1Git], *, statement
+    ) -> Iterable[ReleaseRow]:
         return map(
             ReleaseRow.from_dict, self._execute_with_retries(statement, [release_ids])
         )
@@ -679,6 +688,17 @@ class CqlRunner:
     def directory_get_random(self, *, statement) -> Optional[DirectoryRow]:
         return self._get_random_row(DirectoryRow, statement)
 
+    @_prepared_select_statement(DirectoryRow, "WHERE id in ?")
+    def directory_get(
+        self, directory_ids: List[Sha1Git], *, statement
+    ) -> Iterable[DirectoryRow]:
+        """Return fields from the main directory table (e.g. raw_manifest, but not
+        entries)"""
+        return map(
+            DirectoryRow.from_dict,
+            self._execute_with_retries(statement, [directory_ids]),
+        )
+
     ##########################
     # 'directory_entry' table
     ##########################
@@ -796,14 +816,20 @@ class CqlRunner:
         """
     )
     def snapshot_count_branches_before_name(
-        self, snapshot_id: Sha1Git, before: bytes, *, statement,
+        self,
+        snapshot_id: Sha1Git,
+        before: bytes,
+        *,
+        statement,
     ) -> Dict[Optional[str], int]:
         row = self._execute_with_retries(statement, [snapshot_id, before]).one()
         (nb_none, counts) = row["counts"]
         return {None: nb_none, **counts}
 
     def snapshot_count_branches(
-        self, snapshot_id: Sha1Git, branch_name_exclude_prefix: Optional[bytes] = None,
+        self,
+        snapshot_id: Sha1Git,
+        branch_name_exclude_prefix: Optional[bytes] = None,
     ) -> Dict[Optional[str], int]:
         """Returns a dictionary from type names to the number of branches
         of that type."""
@@ -1016,10 +1042,12 @@ class CqlRunner:
         else:
             return None
 
-    @_prepared_select_statement(OriginVisitRow, "WHERE origin = ?")
-    def origin_visit_get_all(
+    @_prepared_select_statement(OriginVisitRow, "WHERE origin = ? ORDER BY visit DESC")
+    def origin_visit_iter_all(
         self, origin_url: str, *, statement
     ) -> Iterable[OriginVisitRow]:
+        """Returns an iterator on visits for a given origin, ordered by descending
+        visit id."""
         return map(
             OriginVisitRow.from_dict,
             self._execute_with_retries(statement, [origin_url]),
@@ -1093,6 +1121,25 @@ class CqlRunner:
             OriginVisitStatusRow.from_dict, self._execute_with_retries(statement, args)
         )
 
+    @_prepared_select_statement(
+        OriginVisitStatusRow,
+        "WHERE origin = ? AND visit >= ? AND visit <= ? ORDER BY visit ASC, date ASC",
+    )
+    def origin_visit_status_get_all_range(
+        self,
+        origin_url: str,
+        visit_from: int,
+        visit_to: int,
+        *,
+        statement,
+    ) -> Iterable[OriginVisitStatusRow]:
+
+        args = (origin_url, visit_from, visit_to)
+
+        return map(
+            OriginVisitStatusRow.from_dict, self._execute_with_retries(statement, args)
+        )
+
     @_prepared_insert_statement(OriginVisitStatusRow)
     def origin_visit_status_add_one(
         self, visit_update: OriginVisitStatusRow, *, statement
@@ -1100,11 +1147,11 @@ class CqlRunner:
         self._add_one(statement, visit_update)
 
     def origin_visit_status_get_latest(
-        self, origin: str, visit: int,
+        self,
+        origin: str,
+        visit: int,
     ) -> Optional[OriginVisitStatusRow]:
-        """Given an origin visit id, return its latest origin_visit_status
-
-         """
+        """Given an origin visit id, return its latest origin_visit_status"""
         return next(self.origin_visit_status_get(origin, visit), None)
 
     @_prepared_select_statement(
@@ -1113,11 +1160,13 @@ class CqlRunner:
         "WHERE origin = ? AND visit = ? ORDER BY visit DESC, date DESC",
     )
     def origin_visit_status_get(
-        self, origin: str, visit: int, *, statement,
+        self,
+        origin: str,
+        visit: int,
+        *,
+        statement,
     ) -> Iterator[OriginVisitStatusRow]:
-        """Return all origin visit statuses for a given visit
-
-        """
+        """Return all origin visit statuses for a given visit"""
         return map(
             OriginVisitStatusRow.from_dict,
             self._execute_with_retries(statement, [origin, visit]),
@@ -1329,10 +1378,14 @@ class CqlRunner:
             return None
 
     @_prepared_select_statement(
-        ExtIDRow, "WHERE token(extid_type, extid) = ?",
+        ExtIDRow,
+        "WHERE token(extid_type, extid) = ?",
     )
     def extid_get_from_token(self, token: int, *, statement) -> Iterable[ExtIDRow]:
-        return map(ExtIDRow.from_dict, self._execute_with_retries(statement, [token]),)
+        return map(
+            ExtIDRow.from_dict,
+            self._execute_with_retries(statement, [token]),
+        )
 
     # Rows are partitioned by token(extid_type, extid), then ordered (aka. "clustered")
     # by (extid_type, extid, extid_version, ...). This means that, without knowing the
@@ -1351,7 +1404,8 @@ class CqlRunner:
         )
 
     @_prepared_select_statement(
-        ExtIDRow, "WHERE extid_type=? AND extid=?",
+        ExtIDRow,
+        "WHERE extid_type=? AND extid=?",
     )
     def extid_get_from_extid(
         self, extid_type: str, extid: bytes, *, statement
@@ -1362,7 +1416,8 @@ class CqlRunner:
         )
 
     @_prepared_select_statement(
-        ExtIDRow, "WHERE extid_type=? AND extid=? AND extid_version = ?",
+        ExtIDRow,
+        "WHERE extid_type=? AND extid=? AND extid_version = ?",
     )
     def extid_get_from_extid_and_version(
         self, extid_type: str, extid: bytes, extid_version: int, *, statement
