@@ -1,9 +1,10 @@
-# Copyright (C) 2019-2021  The Software Heritage developers
+# Copyright (C) 2019-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 import base64
+from collections import defaultdict
 import datetime
 import itertools
 import operator
@@ -53,11 +54,11 @@ from swh.model.swhids import ObjectType as SwhidObjectType
 from swh.storage.interface import (
     VISIT_STATUSES,
     ListOrder,
+    OriginVisitWithStatuses,
     PagedResult,
     PartialBranches,
     Sha1,
 )
-from swh.storage.metrics import process_metrics, send_metric, timed
 from swh.storage.objstorage import ObjStorage
 from swh.storage.utils import map_optional, now
 from swh.storage.writer import JournalWriter
@@ -151,7 +152,6 @@ class CassandraStorage:
             self._hosts, self._keyspace, self._port, self._consistency_level
         )
 
-    @timed
     def check_config(self, *, check_write: bool) -> bool:
         self._cql_runner.check_read()
 
@@ -255,8 +255,6 @@ class CassandraStorage:
 
         return summary
 
-    @timed
-    @process_metrics
     def content_add(self, content: List[Content]) -> Dict[str, int]:
         to_add = {
             (c.sha1, c.sha1_git, c.sha256, c.blake2s256): c for c in content
@@ -264,7 +262,6 @@ class CassandraStorage:
         contents = [attr.evolve(c, ctime=now()) for c in to_add]
         return self._content_add(list(contents), with_data=True)
 
-    @timed
     def content_update(
         self, contents: List[Dict[str, Any]], keys: List[str] = []
     ) -> None:
@@ -272,17 +269,13 @@ class CassandraStorage:
             "content_update is not supported by the Cassandra backend"
         )
 
-    @timed
-    @process_metrics
     def content_add_metadata(self, content: List[Content]) -> Dict[str, int]:
         return self._content_add(content, with_data=False)
 
-    @timed
     def content_get_data(self, content: Sha1) -> Optional[bytes]:
         # FIXME: Make this method support slicing the `data`
         return self.objstorage.content_get(content)
 
-    @timed
     def content_get_partition(
         self,
         partition_id: int,
@@ -324,7 +317,6 @@ class CassandraStorage:
         assert len(contents) <= limit
         return PagedResult(results=contents, next_page_token=next_page_token)
 
-    @timed
     def content_get(
         self, contents: List[bytes], algo: str = "sha1"
     ) -> List[Optional[Content]]:
@@ -344,13 +336,13 @@ class CassandraStorage:
             contents_by_hash[key(content)] = content
         return [contents_by_hash.get(hash_) for hash_ in contents]
 
-    @timed
     def content_find(self, content: Dict[str, Any]) -> List[Content]:
         return self._content_find_many([content])
 
     def _content_find_many(self, contents: List[Dict[str, Any]]) -> List[Content]:
         # Find an algorithm that is common to all the requested contents.
         # It will be used to do an initial filtering efficiently.
+        # TODO: prioritize sha256, we can do more efficient lookups from this hash.
         filter_algos = set(HASH_ALGORITHMS)
         for content in contents:
             filter_algos &= set(content)
@@ -384,7 +376,6 @@ class CassandraStorage:
                 pass
         return results
 
-    @timed
     def content_missing(
         self, contents: List[Dict[str, Any]], key_hash: str = "sha1"
     ) -> Iterable[bytes]:
@@ -402,22 +393,62 @@ class CassandraStorage:
                 contents_with_missing_hashes.append(content)
 
         # These contents can be queried efficiently directly in the main table
-        for content in self._cql_runner.content_missing_from_hashes(
+        for content in self._cql_runner.content_missing_from_all_hashes(
             contents_with_all_hashes
         ):
             yield content[key_hash]
 
-        # For these, we need the expensive index lookups + main table.
-        for content in contents_with_missing_hashes:
-            res = self.content_find(content)
-            if not res:
-                yield content[key_hash]
+        if contents_with_missing_hashes:
+            # For these, we need the expensive index lookups + main table.
+
+            # Get all contents in the database that match (at least) one of the
+            # requested contents, concurrently.
+            found_contents = self._content_find_many(contents_with_missing_hashes)
+
+            # Bucket the known contents by hash
+            found_contents_by_hash: Dict[str, Dict[str, list]] = {
+                algo: defaultdict(list) for algo in DEFAULT_ALGORITHMS
+            }
+            for found_content in found_contents:
+                for algo in DEFAULT_ALGORITHMS:
+                    found_contents_by_hash[algo][found_content.get_hash(algo)].append(
+                        found_content
+                    )
+
+            # For each of the requested contents, check if they are in the
+            # 'found_contents' set (via 'found_contents_by_hash' for efficient access,
+            # since we need to check using dict inclusion instead of hash+equality)
+            for missing_content in contents_with_missing_hashes:
+                # Pick any of the algorithms provided in missing_content
+                algo = next(algo for (algo, hash_) in missing_content.items() if hash_)
+
+                # Get the list of found_contents that match this hash in the
+                # missing_content. (its length is at most 1, unless there is a
+                # collision)
+                found_contents_with_same_hash = found_contents_by_hash[algo][
+                    missing_content[algo]
+                ]
+
+                # Check if there is a found_content that matches all hashes in the
+                # missing_content.
+                # This is functionally equivalent to 'for found_content in
+                # found_contents', but runs almost in constant time (it is linear
+                # in the number of hash collisions) instead of linear.
+                # This allows this function to run in linear time overall instead of
+                # quadratic.
+                for found_content in found_contents_with_same_hash:
+                    # check if the found_content.hashes() dictionary contains a superset
+                    # of the (key, value) pairs in missing_content
+                    if missing_content.items() <= found_content.hashes().items():
+                        # Found!
+                        break
+                else:
+                    # Not found
+                    yield missing_content[key_hash]
 
-    @timed
     def content_missing_per_sha1(self, contents: List[bytes]) -> Iterable[bytes]:
         return self.content_missing([{"sha1": c} for c in contents])
 
-    @timed
     def content_missing_per_sha1_git(
         self, contents: List[Sha1Git]
     ) -> Iterable[Sha1Git]:
@@ -425,7 +456,6 @@ class CassandraStorage:
             [{"sha1_git": c} for c in contents], key_hash="sha1_git"
         )
 
-    @timed
     def content_get_random(self) -> Sha1Git:
         content = self._cql_runner.content_get_random()
         assert content, "Could not find any content"
@@ -457,13 +487,10 @@ class CassandraStorage:
 
         return {"skipped_content:add": len(contents)}
 
-    @timed
-    @process_metrics
     def skipped_content_add(self, content: List[SkippedContent]) -> Dict[str, int]:
         contents = [attr.evolve(c, ctime=now()) for c in content]
         return self._skipped_content_add(contents)
 
-    @timed
     def skipped_content_missing(
         self, contents: List[Dict[str, Any]]
     ) -> Iterable[Dict[str, Any]]:
@@ -471,8 +498,6 @@ class CassandraStorage:
             if not self._cql_runner.skipped_content_get_from_pk(content):
                 yield {algo: content[algo] for algo in DEFAULT_ALGORITHMS}
 
-    @timed
-    @process_metrics
     def directory_add(self, directories: List[Directory]) -> Dict[str, int]:
         to_add = {d.id: d for d in directories}.values()
         if not self._allow_overwrite:
@@ -510,7 +535,6 @@ class CassandraStorage:
 
         return {"directory:add": len(directories)}
 
-    @timed
     def directory_missing(self, directories: List[Sha1Git]) -> Iterable[Sha1Git]:
         return self._cql_runner.directory_missing(directories)
 
@@ -576,7 +600,6 @@ class CassandraStorage:
                     ret["target"], True, prefix + ret["name"] + b"/"
                 )
 
-    @timed
     def directory_entry_get_by_path(
         self, directory: Sha1Git, paths: List[bytes]
     ) -> Optional[Dict[str, Any]]:
@@ -616,13 +639,11 @@ class CassandraStorage:
             first_item["target"], paths[1:], prefix + paths[0] + b"/"
         )
 
-    @timed
     def directory_ls(
         self, directory: Sha1Git, recursive: bool = False
     ) -> Iterable[Dict[str, Any]]:
         yield from self._directory_ls(directory, recursive)
 
-    @timed
     def directory_get_entries(
         self,
         directory_id: Sha1Git,
@@ -647,14 +668,19 @@ class CassandraStorage:
             next_page_token = None
         return PagedResult(results=entries, next_page_token=next_page_token)
 
-    @timed
+    def directory_get_raw_manifest(
+        self, directory_ids: List[Sha1Git]
+    ) -> Dict[Sha1Git, Optional[bytes]]:
+        return {
+            dir_.id: dir_.raw_manifest
+            for dir_ in self._cql_runner.directory_get(directory_ids)
+        }
+
     def directory_get_random(self) -> Sha1Git:
         directory = self._cql_runner.directory_get_random()
         assert directory, "Could not find any directory"
         return directory.id
 
-    @timed
-    @process_metrics
     def revision_add(self, revisions: List[Revision]) -> Dict[str, int]:
         # Filter-out revisions already in the database
         if not self._allow_overwrite:
@@ -682,12 +708,12 @@ class CassandraStorage:
 
         return {"revision:add": len(revisions)}
 
-    @timed
     def revision_missing(self, revisions: List[Sha1Git]) -> Iterable[Sha1Git]:
         return self._cql_runner.revision_missing(revisions)
 
-    @timed
-    def revision_get(self, revision_ids: List[Sha1Git]) -> List[Optional[Revision]]:
+    def revision_get(
+        self, revision_ids: List[Sha1Git], ignore_displayname: bool = False
+    ) -> List[Optional[Revision]]:
         rows = self._cql_runner.revision_get(revision_ids)
         revisions: Dict[Sha1Git, Revision] = {}
         for row in rows:
@@ -710,7 +736,8 @@ class CassandraStorage:
         limit: Optional[int],
         short: bool,
     ) -> Union[
-        Iterable[Dict[str, Any]], Iterable[Tuple[Sha1Git, Tuple[Sha1Git, ...]]],
+        Iterable[Dict[str, Any]],
+        Iterable[Tuple[Sha1Git, Tuple[Sha1Git, ...]]],
     ]:
         if limit and len(seen) >= limit:
             return
@@ -753,28 +780,26 @@ class CassandraStorage:
                 yield rev.to_dict()
                 yield from self._get_parent_revs(parents, seen, limit, short)
 
-    @timed
     def revision_log(
-        self, revisions: List[Sha1Git], limit: Optional[int] = None
+        self,
+        revisions: List[Sha1Git],
+        ignore_displayname: bool = False,
+        limit: Optional[int] = None,
     ) -> Iterable[Optional[Dict[str, Any]]]:
         seen: Set[Sha1Git] = set()
         yield from self._get_parent_revs(revisions, seen, limit, False)
 
-    @timed
     def revision_shortlog(
         self, revisions: List[Sha1Git], limit: Optional[int] = None
     ) -> Iterable[Optional[Tuple[Sha1Git, Tuple[Sha1Git, ...]]]]:
         seen: Set[Sha1Git] = set()
         yield from self._get_parent_revs(revisions, seen, limit, True)
 
-    @timed
     def revision_get_random(self) -> Sha1Git:
         revision = self._cql_runner.revision_get_random()
         assert revision, "Could not find any revision"
         return revision.id
 
-    @timed
-    @process_metrics
     def release_add(self, releases: List[Release]) -> Dict[str, int]:
         if not self._allow_overwrite:
             to_add = {r.id: r for r in releases}.values()
@@ -788,12 +813,12 @@ class CassandraStorage:
 
         return {"release:add": len(releases)}
 
-    @timed
     def release_missing(self, releases: List[Sha1Git]) -> Iterable[Sha1Git]:
         return self._cql_runner.release_missing(releases)
 
-    @timed
-    def release_get(self, releases: List[Sha1Git]) -> List[Optional[Release]]:
+    def release_get(
+        self, releases: List[Sha1Git], ignore_displayname: bool = False
+    ) -> List[Optional[Release]]:
         rows = self._cql_runner.release_get(releases)
         rels: Dict[Sha1Git, Release] = {}
         for row in rows:
@@ -802,14 +827,11 @@ class CassandraStorage:
 
         return [rels.get(rel_id) for rel_id in releases]
 
-    @timed
     def release_get_random(self) -> Sha1Git:
         release = self._cql_runner.release_get_random()
         assert release, "Could not find any release"
         return release.id
 
-    @timed
-    @process_metrics
     def snapshot_add(self, snapshots: List[Snapshot]) -> Dict[str, int]:
         if not self._allow_overwrite:
             to_add = {s.id: s for s in snapshots}.values()
@@ -843,11 +865,9 @@ class CassandraStorage:
 
         return {"snapshot:add": len(snapshots)}
 
-    @timed
     def snapshot_missing(self, snapshots: List[Sha1Git]) -> Iterable[Sha1Git]:
         return self._cql_runner.snapshot_missing(snapshots)
 
-    @timed
     def snapshot_get(self, snapshot_id: Sha1Git) -> Optional[Dict[str, Any]]:
         d = self.snapshot_get_branches(snapshot_id)
         if d is None:
@@ -861,9 +881,10 @@ class CassandraStorage:
             "next_branch": d["next_branch"],
         }
 
-    @timed
     def snapshot_count_branches(
-        self, snapshot_id: Sha1Git, branch_name_exclude_prefix: Optional[bytes] = None,
+        self,
+        snapshot_id: Sha1Git,
+        branch_name_exclude_prefix: Optional[bytes] = None,
     ) -> Optional[Dict[Optional[str], int]]:
         if self._cql_runner.snapshot_missing([snapshot_id]):
             # Makes sure we don't fetch branches for a snapshot that is
@@ -874,7 +895,6 @@ class CassandraStorage:
             snapshot_id, branch_name_exclude_prefix
         )
 
-    @timed
     def snapshot_get_branches(
         self,
         snapshot_id: Sha1Git,
@@ -950,20 +970,18 @@ class CassandraStorage:
             next_branch=last_branch,
         )
 
-    @timed
     def snapshot_get_random(self) -> Sha1Git:
         snapshot = self._cql_runner.snapshot_get_random()
         assert snapshot, "Could not find any snapshot"
         return snapshot.id
 
-    @timed
     def object_find_by_sha1_git(self, ids: List[Sha1Git]) -> Dict[Sha1Git, List[Dict]]:
         results: Dict[Sha1Git, List[Dict]] = {id_: [] for id_ in ids}
         missing_ids = set(ids)
 
         # Mind the order, revision is the most likely one for a given ID,
         # so we check revisions first.
-        queries: List[Tuple[str, Callable[[List[Sha1Git]], List[Sha1Git]]]] = [
+        queries: List[Tuple[str, Callable[[List[Sha1Git]], Iterable[Sha1Git]]]] = [
             ("revision", self._cql_runner.revision_missing),
             ("release", self._cql_runner.release_missing),
             ("content", self.content_missing_per_sha1_git),
@@ -974,7 +992,10 @@ class CassandraStorage:
             found_ids = missing_ids - set(query_fn(list(missing_ids)))
             for sha1_git in found_ids:
                 results[sha1_git].append(
-                    {"sha1_git": sha1_git, "type": object_type,}
+                    {
+                        "sha1_git": sha1_git,
+                        "type": object_type,
+                    }
                 )
                 missing_ids.remove(sha1_git)
 
@@ -984,15 +1005,11 @@ class CassandraStorage:
 
         return results
 
-    @timed
     def origin_get(self, origins: List[str]) -> Iterable[Optional[Origin]]:
         return [self.origin_get_one(origin) for origin in origins]
 
-    @timed
     def origin_get_one(self, origin_url: str) -> Optional[Origin]:
-        """Given an origin url, return the origin if it exists, None otherwise
-
-        """
+        """Given an origin url, return the origin if it exists, None otherwise"""
         rows = list(self._cql_runner.origin_get_by_url(origin_url))
         if rows:
             assert len(rows) == 1
@@ -1000,7 +1017,6 @@ class CassandraStorage:
         else:
             return None
 
-    @timed
     def origin_get_by_sha1(self, sha1s: List[bytes]) -> List[Optional[Dict[str, Any]]]:
         results = []
         for sha1 in sha1s:
@@ -1009,7 +1025,6 @@ class CassandraStorage:
             results.append(origin)
         return results
 
-    @timed
     def origin_list(
         self, page_token: Optional[str] = None, limit: int = 100
     ) -> PagedResult[Origin]:
@@ -1038,7 +1053,6 @@ class CassandraStorage:
 
         return PagedResult(results=origins, next_page_token=next_page_token)
 
-    @timed
     def origin_search(
         self,
         url_pattern: str,
@@ -1086,7 +1100,6 @@ class CassandraStorage:
         assert len(origins) <= limit
         return PagedResult(results=origins, next_page_token=next_page_token)
 
-    @timed
     def origin_count(
         self, url_pattern: str, regexp: bool = False, with_visit: bool = False
     ) -> int:
@@ -1094,12 +1107,9 @@ class CassandraStorage:
             "The Cassandra backend does not implement origin_count"
         )
 
-    @timed
     def origin_snapshot_get_all(self, origin_url: str) -> List[Sha1Git]:
         return list(self._cql_runner.origin_snapshot_get_all(origin_url))
 
-    @timed
-    @process_metrics
     def origin_add(self, origins: List[Origin]) -> Dict[str, int]:
         if not self._allow_overwrite:
             to_add = {o.url: o for o in origins}.values()
@@ -1112,7 +1122,6 @@ class CassandraStorage:
             )
         return {"origin:add": len(origins)}
 
-    @timed
     def origin_visit_add(self, visits: List[OriginVisit]) -> Iterable[OriginVisit]:
         for visit in visits:
             origin = self.origin_get_one(visit.origin)
@@ -1120,9 +1129,7 @@ class CassandraStorage:
                 raise StorageArgumentException("Unknown origin %s", visit.origin)
 
         all_visits = []
-        nb_visits = 0
         for visit in visits:
-            nb_visits += 1
             if visit.visit:
                 # Set origin.next_visit_id = max(origin.next_visit_id, visit.visit+1)
                 # so the next loader run does not reuse the id.
@@ -1146,7 +1153,6 @@ class CassandraStorage:
                     snapshot=None,
                 )
             )
-        send_metric("origin_visit:add", count=nb_visits, method_name="origin_visit")
         return all_visits
 
     def _origin_visit_status_add(self, visit_status: OriginVisitStatus) -> None:
@@ -1167,8 +1173,6 @@ class CassandraStorage:
             converters.visit_status_to_row(visit_status)
         )
 
-    @timed
-    @process_metrics
     def origin_visit_status_add(
         self, visit_statuses: List[OriginVisitStatus]
     ) -> Dict[str, int]:
@@ -1205,9 +1209,7 @@ class CassandraStorage:
         }
 
     def _origin_visit_get_latest_status(self, visit: OriginVisit) -> OriginVisitStatus:
-        """Retrieve the latest visit status information for the origin visit object.
-
-        """
+        """Retrieve the latest visit status information for the origin visit object."""
         assert visit.visit
         row = self._cql_runner.origin_visit_status_get_latest(visit.origin, visit.visit)
         assert row is not None
@@ -1222,7 +1224,6 @@ class CassandraStorage:
             "date": visit.date.replace(tzinfo=datetime.timezone.utc),
         }
 
-    @timed
     def origin_visit_get(
         self,
         origin: str,
@@ -1251,7 +1252,58 @@ class CassandraStorage:
 
         return PagedResult(results=visits, next_page_token=next_page_token)
 
-    @timed
+    def origin_visit_get_with_statuses(
+        self,
+        origin: str,
+        allowed_statuses: Optional[List[str]] = None,
+        require_snapshot: bool = False,
+        page_token: Optional[str] = None,
+        order: ListOrder = ListOrder.ASC,
+        limit: int = 10,
+    ) -> PagedResult[OriginVisitWithStatuses]:
+        next_page_token = None
+        visit_from = None if page_token is None else int(page_token)
+        extra_limit = limit + 1
+
+        # First get visits (plus one so we can use it as the next page token if any)
+        rows = self._cql_runner.origin_visit_get(origin, visit_from, extra_limit, order)
+        visits: List[OriginVisit] = [converters.row_to_visit(row) for row in rows]
+
+        if visits:
+            assert visits[0].visit is not None
+            assert visits[-1].visit is not None
+            visit_from = min(visits[0].visit, visits[-1].visit)
+            visit_to = max(visits[0].visit, visits[-1].visit)
+
+            # Then, fetch all statuses associated to these visits
+            statuses_rows = self._cql_runner.origin_visit_status_get_all_range(
+                origin, visit_from, visit_to
+            )
+            visit_statuses: Dict[int, List[OriginVisitStatus]] = defaultdict(list)
+            for status_row in statuses_rows:
+                if allowed_statuses and status_row.status not in allowed_statuses:
+                    continue
+                if require_snapshot and status_row.snapshot is None:
+                    continue
+                visit_status = converters.row_to_visit_status(status_row)
+                visit_statuses[visit_status.visit].append(visit_status)
+
+            # Add pagination if there are more visits
+            assert len(visits) <= extra_limit
+            if len(visits) == extra_limit:
+                # excluding that visit from the result to respect the limit size
+                visits = visits[:limit]
+                # last visit id is the next page token
+                next_page_token = str(visits[-1].visit)
+
+        results = [
+            OriginVisitWithStatuses(visit=visit, statuses=visit_statuses[visit.visit])
+            for visit in visits
+            if visit.visit is not None
+        ]
+
+        return PagedResult(results=results, next_page_token=next_page_token)
+
     def origin_visit_status_get(
         self,
         origin: str,
@@ -1278,14 +1330,13 @@ class CassandraStorage:
 
         return PagedResult(results=visit_statuses, next_page_token=next_page_token)
 
-    @timed
     def origin_visit_find_by_date(
         self, origin: str, visit_date: datetime.datetime
     ) -> Optional[OriginVisit]:
         # Iterator over all the visits of the origin
         # This should be ok for now, as there aren't too many visits
         # per origin.
-        rows = list(self._cql_runner.origin_visit_get_all(origin))
+        rows = list(self._cql_runner.origin_visit_iter_all(origin))
 
         def key(visit):
             dt = visit.date.replace(tzinfo=datetime.timezone.utc) - visit_date
@@ -1295,14 +1346,12 @@ class CassandraStorage:
             return converters.row_to_visit(min(rows, key=key))
         return None
 
-    @timed
     def origin_visit_get_by(self, origin: str, visit: int) -> Optional[OriginVisit]:
         row = self._cql_runner.origin_visit_get_one(origin, visit)
         if row:
             return converters.row_to_visit(row)
         return None
 
-    @timed
     def origin_visit_get_latest(
         self,
         origin: str,
@@ -1315,9 +1364,7 @@ class CassandraStorage:
                 f"Unknown allowed statuses {','.join(allowed_statuses)}, only "
                 f"{','.join(VISIT_STATUSES)} authorized"
             )
-        # TODO: Do not fetch all visits
-        rows = self._cql_runner.origin_visit_get_all(origin)
-        latest_visit = None
+        rows = self._cql_runner.origin_visit_iter_all(origin)
         for row in rows:
             visit = self._format_origin_visit_row(row)
             for status_row in self._cql_runner.origin_visit_status_get(
@@ -1331,26 +1378,15 @@ class CassandraStorage:
                 if require_snapshot and updated_visit["snapshot"] is None:
                     continue
 
-                # updated_visit is a candidate
-                if latest_visit is not None:
-                    if updated_visit["date"] < latest_visit["date"]:
-                        continue
-                    assert (
-                        updated_visit["visit"] >= latest_visit["visit"]
-                    ), "Cassandra returned visits not ordered by increasing visit id."
+                return OriginVisit(
+                    origin=visit["origin"],
+                    visit=visit["visit"],
+                    date=visit["date"],
+                    type=visit["type"],
+                )
 
-                latest_visit = updated_visit
+        return None
 
-        if latest_visit is None:
-            return None
-        return OriginVisit(
-            origin=latest_visit["origin"],
-            visit=latest_visit["visit"],
-            date=latest_visit["date"],
-            type=latest_visit["type"],
-        )
-
-    @timed
     def origin_visit_status_get_latest(
         self,
         origin_url: str,
@@ -1373,7 +1409,6 @@ class CassandraStorage:
             return None
         return converters.row_to_visit_status(rows[0])
 
-    @timed
     def origin_visit_status_get_random(self, type: str) -> Optional[OriginVisitStatus]:
         back_in_the_day = now() - datetime.timedelta(weeks=12)  # 3 months back
 
@@ -1389,7 +1424,6 @@ class CassandraStorage:
                 return visit_status
         return None
 
-    @timed
     def stat_counters(self):
         rows = self._cql_runner.stat_counters()
         keys = (
@@ -1406,12 +1440,9 @@ class CassandraStorage:
         stats.update({row.object_type: row.count for row in rows})
         return stats
 
-    @timed
     def refresh_stat_counters(self):
         pass
 
-    @timed
-    @process_metrics
     def raw_extrinsic_metadata_add(
         self, metadata: List[RawExtrinsicMetadata]
     ) -> Dict[str, int]:
@@ -1471,7 +1502,6 @@ class CassandraStorage:
             f"{type.value}_metadata:add": count for (type, count) in counter.items()
         }
 
-    @timed
     def raw_extrinsic_metadata_get(
         self,
         target: ExtendedSWHID,
@@ -1487,7 +1517,11 @@ class CassandraStorage:
                     "page_token is inconsistent with the value of 'after'."
                 )
             entries = self._cql_runner.raw_extrinsic_metadata_get_after_date_and_id(
-                str(target), authority.type.value, authority.url, after_date, id_,
+                str(target),
+                authority.type.value,
+                authority.url,
+                after_date,
+                id_,
             )
         elif after is not None:
             entries = self._cql_runner.raw_extrinsic_metadata_get_after_date(
@@ -1512,14 +1546,21 @@ class CassandraStorage:
             assert len(results) == limit
             last_result = results[-1]
             next_page_token: Optional[str] = base64.b64encode(
-                msgpack_dumps((last_result.discovery_date, last_result.id,))
+                msgpack_dumps(
+                    (
+                        last_result.discovery_date,
+                        last_result.id,
+                    )
+                )
             ).decode()
         else:
             next_page_token = None
 
-        return PagedResult(next_page_token=next_page_token, results=results,)
+        return PagedResult(
+            next_page_token=next_page_token,
+            results=results,
+        )
 
-    @timed
     def raw_extrinsic_metadata_get_by_ids(
         self, ids: List[Sha1Git]
     ) -> List[RawExtrinsicMetadata]:
@@ -1542,7 +1583,6 @@ class CassandraStorage:
 
         return list(results)
 
-    @timed
     def raw_extrinsic_metadata_get_authorities(
         self, target: ExtendedSWHID
     ) -> List[MetadataAuthority]:
@@ -1555,53 +1595,56 @@ class CassandraStorage:
             )
         ]
 
-    @timed
-    @process_metrics
     def metadata_fetcher_add(self, fetchers: List[MetadataFetcher]) -> Dict[str, int]:
         self.journal_writer.metadata_fetcher_add(fetchers)
         for fetcher in fetchers:
             self._cql_runner.metadata_fetcher_add(
-                MetadataFetcherRow(name=fetcher.name, version=fetcher.version,)
+                MetadataFetcherRow(
+                    name=fetcher.name,
+                    version=fetcher.version,
+                )
             )
         return {"metadata_fetcher:add": len(fetchers)}
 
-    @timed
     def metadata_fetcher_get(
         self, name: str, version: str
     ) -> Optional[MetadataFetcher]:
         fetcher = self._cql_runner.metadata_fetcher_get(name, version)
         if fetcher:
-            return MetadataFetcher(name=fetcher.name, version=fetcher.version,)
+            return MetadataFetcher(
+                name=fetcher.name,
+                version=fetcher.version,
+            )
         else:
             return None
 
-    @timed
-    @process_metrics
     def metadata_authority_add(
         self, authorities: List[MetadataAuthority]
     ) -> Dict[str, int]:
         self.journal_writer.metadata_authority_add(authorities)
         for authority in authorities:
             self._cql_runner.metadata_authority_add(
-                MetadataAuthorityRow(url=authority.url, type=authority.type.value,)
+                MetadataAuthorityRow(
+                    url=authority.url,
+                    type=authority.type.value,
+                )
             )
         return {"metadata_authority:add": len(authorities)}
 
-    @timed
     def metadata_authority_get(
         self, type: MetadataAuthorityType, url: str
     ) -> Optional[MetadataAuthority]:
         authority = self._cql_runner.metadata_authority_get(type.value, url)
         if authority:
             return MetadataAuthority(
-                type=MetadataAuthorityType(authority.type), url=authority.url,
+                type=MetadataAuthorityType(authority.type),
+                url=authority.url,
             )
         else:
             return None
 
     # ExtID tables
-    @timed
-    @process_metrics
+
     def extid_add(self, ids: List[ExtID]) -> Dict[str, int]:
         if not self._allow_overwrite:
             extids = [
@@ -1634,14 +1677,15 @@ class CassandraStorage:
             )
             (token, insertion_finalizer) = self._cql_runner.extid_add_prepare(extidrow)
             indexrow = ExtIDByTargetRow(
-                target_type=target_type, target=target, target_token=token,
+                target_type=target_type,
+                target=target,
+                target_token=token,
             )
             self._cql_runner.extid_index_add_one(indexrow)
             insertion_finalizer()
             inserted += 1
         return {"extid:add": inserted}
 
-    @timed
     def extid_get_from_extid(
         self, id_type: str, ids: List[bytes], version: Optional[int] = None
     ) -> List[ExtID]:
@@ -1659,14 +1703,14 @@ class CassandraStorage:
                     extid_version=extidrow.extid_version,
                     extid=extidrow.extid,
                     target=CoreSWHID(
-                        object_type=extidrow.target_type, object_id=extidrow.target,
+                        object_type=extidrow.target_type,
+                        object_id=extidrow.target,
                     ),
                 )
                 for extidrow in extidrows
             )
         return result
 
-    @timed
     def extid_get_from_target(
         self,
         target_type: SwhidObjectType,
@@ -1704,9 +1748,7 @@ class CassandraStorage:
 
     # Misc
     def clear_buffers(self, object_types: Sequence[str] = ()) -> None:
-        """Do nothing
-
-        """
+        """Do nothing"""
         return None
 
     def flush(self, object_types: Sequence[str] = ()) -> Dict[str, int]:
