@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -205,7 +205,10 @@ class InMemoryCqlRunner:
         return self._contents.get_random()
 
     def content_get_token_range(
-        self, start: int, end: int, limit: int,
+        self,
+        start: int,
+        end: int,
+        limit: int,
     ) -> Iterable[Tuple[int, ContentRow]]:
         matches = [
             (token, row)
@@ -216,7 +219,7 @@ class InMemoryCqlRunner:
         matches.sort()
         return matches[0:limit]
 
-    def content_missing_from_hashes(
+    def content_missing_from_all_hashes(
         self, contents_hashes: List[Dict[str, bytes]]
     ) -> Iterator[Dict[str, bytes]]:
         for content_hashes in contents_hashes:
@@ -299,6 +302,12 @@ class InMemoryCqlRunner:
     def directory_get_random(self) -> Optional[DirectoryRow]:
         return self._directories.get_random()
 
+    def directory_get(self, directory_ids: List[Sha1Git]) -> Iterable[DirectoryRow]:
+        for id_ in directory_ids:
+            row = self._directories.get_from_primary_key((id_,))
+            if row:
+                yield row
+
     ##########################
     # 'directory_entry' table
     ##########################
@@ -342,7 +351,9 @@ class InMemoryCqlRunner:
             if self._revisions.get_from_primary_key((id_,)) is not None:
                 yield id_
 
-    def revision_get(self, revision_ids: List[Sha1Git]) -> Iterable[RevisionRow]:
+    def revision_get(
+        self, revision_ids: List[Sha1Git], ignore_displayname: bool = False
+    ) -> Iterable[RevisionRow]:
         for id_ in revision_ids:
             row = self._revisions.get_from_primary_key((id_,))
             if row:
@@ -377,7 +388,9 @@ class InMemoryCqlRunner:
         self._releases.insert(release)
         self.increment_counter("release", 1)
 
-    def release_get(self, release_ids: List[str]) -> Iterable[ReleaseRow]:
+    def release_get(
+        self, release_ids: List[str], ignore_displayname: bool = False
+    ) -> Iterable[ReleaseRow]:
         for id_ in release_ids:
             row = self._releases.get_from_primary_key((id_,))
             if row:
@@ -412,7 +425,9 @@ class InMemoryCqlRunner:
         self._snapshot_branches.insert(branch)
 
     def snapshot_count_branches(
-        self, snapshot_id: Sha1Git, branch_name_exclude_prefix: Optional[bytes] = None,
+        self,
+        snapshot_id: Sha1Git,
+        branch_name_exclude_prefix: Optional[bytes] = None,
     ) -> Dict[Optional[str], int]:
         """Returns a dictionary from type names to the number of branches
         of that type."""
@@ -496,7 +511,11 @@ class InMemoryCqlRunner:
     ##########################
 
     def origin_visit_get(
-        self, origin_url: str, last_visit: Optional[int], limit: int, order: ListOrder,
+        self,
+        origin_url: str,
+        last_visit: Optional[int],
+        limit: int,
+        order: ListOrder,
     ) -> Iterable[OriginVisitRow]:
         visits = list(self._origin_visits.get_from_partition_key((origin_url,)))
 
@@ -521,8 +540,8 @@ class InMemoryCqlRunner:
     ) -> Optional[OriginVisitRow]:
         return self._origin_visits.get_from_primary_key((origin_url, visit_id))
 
-    def origin_visit_get_all(self, origin_url: str) -> Iterable[OriginVisitRow]:
-        return self._origin_visits.get_from_partition_key((origin_url,))
+    def origin_visit_iter_all(self, origin_url: str) -> Iterable[OriginVisitRow]:
+        return reversed(list(self._origin_visits.get_from_partition_key((origin_url,))))
 
     def origin_visit_iter(self, start_token: int) -> Iterator[OriginVisitRow]:
         """Returns all origin visits in order from this token,
@@ -557,24 +576,37 @@ class InMemoryCqlRunner:
 
         return statuses[0:limit]
 
+    def origin_visit_status_get_all_range(
+        self, origin: str, first_visit: int, last_visit: int
+    ) -> Iterable[OriginVisitStatusRow]:
+        statuses = [
+            s
+            for s in self._origin_visit_statuses.get_from_partition_key((origin,))
+            if s.visit >= first_visit and s.visit <= last_visit
+        ]
+
+        statuses.sort(key=lambda s: (s.visit, s.date))
+
+        return statuses
+
     def origin_visit_status_add_one(self, visit_update: OriginVisitStatusRow) -> None:
         self._origin_visit_statuses.insert(visit_update)
         self.increment_counter("origin_visit_status", 1)
 
     def origin_visit_status_get_latest(
-        self, origin: str, visit: int,
+        self,
+        origin: str,
+        visit: int,
     ) -> Optional[OriginVisitStatusRow]:
-        """Given an origin visit id, return its latest origin_visit_status
-
-         """
+        """Given an origin visit id, return its latest origin_visit_status"""
         return next(self.origin_visit_status_get(origin, visit), None)
 
     def origin_visit_status_get(
-        self, origin: str, visit: int,
+        self,
+        origin: str,
+        visit: int,
     ) -> Iterator[OriginVisitStatusRow]:
-        """Return all origin visit statuses for a given visit
-
-        """
+        """Return all origin visit statuses for a given visit"""
         statuses = [
             s
             for s in self._origin_visit_statuses.get_from_partition_key((origin,))
@@ -584,9 +616,7 @@ class InMemoryCqlRunner:
         return iter(statuses)
 
     def origin_snapshot_get_all(self, origin: str) -> Iterator[Sha1Git]:
-        """Return all snapshots for a given origin
-
-        """
+        """Return all snapshots for a given origin"""
         return iter(
             {
                 s.snapshot
@@ -705,7 +735,11 @@ class InMemoryCqlRunner:
         pass
 
     def extid_get_from_pk(
-        self, extid_type: str, extid: bytes, extid_version: int, target: ExtendedSWHID,
+        self,
+        extid_type: str,
+        extid: bytes,
+        extid_version: int,
+        target: ExtendedSWHID,
     ) -> Optional[ExtIDRow]:
         primary_key = self._extid.primary_key_from_dict(
             dict(
@@ -719,7 +753,9 @@ class InMemoryCqlRunner:
         return self._extid.get_from_primary_key(primary_key)
 
     def extid_get_from_extid(
-        self, extid_type: str, extid: bytes,
+        self,
+        extid_type: str,
+        extid: bytes,
     ) -> Iterable[ExtIDRow]:
         return (
             row
@@ -728,7 +764,10 @@ class InMemoryCqlRunner:
         )
 
     def extid_get_from_extid_and_version(
-        self, extid_type: str, extid: bytes, extid_version: int,
+        self,
+        extid_type: str,
+        extid: bytes,
+        extid_version: int,
     ) -> Iterable[ExtIDRow]:
         return (
             row
@@ -739,7 +778,11 @@ class InMemoryCqlRunner:
         )
 
     def _extid_get_from_target_with_type_and_version(
-        self, target_type: str, target: bytes, extid_type: str, extid_version: int,
+        self,
+        target_type: str,
+        target: bytes,
+        extid_type: str,
+        extid_version: int,
     ) -> Iterable[ExtIDRow]:
         return (
             row
@@ -751,7 +794,9 @@ class InMemoryCqlRunner:
         )
 
     def _extid_get_from_target(
-        self, target_type: str, target: bytes,
+        self,
+        target_type: str,
+        target: bytes,
     ) -> Iterable[ExtIDRow]:
         return (
             row
