@@ -74,7 +74,16 @@ def db_to_author(
     """
     if fullname is None:
         return None
-    return Person(fullname=fullname, name=name, email=email,)
+
+    if name is None and email is None:
+        # The fullname hasn't been parsed, try that again
+        return Person.from_fullname(fullname)
+
+    return Person(
+        fullname=fullname,
+        name=name,
+        email=email,
+    )
 
 
 def db_to_git_headers(db_git_headers):
@@ -86,16 +95,14 @@ def db_to_git_headers(db_git_headers):
 
 def db_to_date(
     date: Optional[datetime.datetime],
-    offset: int,
-    neg_utc_offset: Optional[bool],
-    offset_bytes: Optional[bytes],
+    offset_bytes: bytes,
 ) -> Optional[TimestampWithTimezone]:
     """Convert the DB representation of a date to a swh-model compatible date.
 
     Args:
         date: a date pulled out of the database
-        offset: an integer number of minutes representing an UTC offset
-        neg_utc_offset: whether an utc offset is negative
+        offset_bytes: a byte representation of the latter two, usually as "+HHMM"
+          or "-HHMM"
 
     Returns:
         a TimestampWithTimezone, or None if the date is None.
@@ -105,24 +112,13 @@ def db_to_date(
     if date is None:
         return None
 
-    if neg_utc_offset is None:
-        # For older versions of the database that were not migrated to schema v160
-        neg_utc_offset = False
-
-    kwargs = {}
-    if offset_bytes:
-        # TODO: remove the conditional after migration is complete.
-        kwargs["offset_bytes"] = offset_bytes
-
     return TimestampWithTimezone(
         timestamp=Timestamp(
             # we use floor() instead of int() to round down, because of negative dates
             seconds=math.floor(date.timestamp()),
             microseconds=date.microsecond,
         ),
-        offset=offset,
-        negative_utc=neg_utc_offset,
-        **kwargs,
+        offset_bytes=offset_bytes,
     )
 
 
@@ -136,9 +132,6 @@ def date_to_db(ts_with_tz: Optional[TimestampWithTimezone]) -> Dict[str, Any]:
         dict: a dictionary with these keys:
 
             - timestamp: a date in ISO format
-            - offset: the UTC offset in minutes
-            - neg_utc_offset: a boolean indicating whether a null offset is
-              negative or positive.
             - offset_bytes: a byte representation of the latter two, usually as "+HHMM"
               or "-HHMM"
 
@@ -155,15 +148,15 @@ def date_to_db(ts_with_tz: Optional[TimestampWithTimezone]) -> Dict[str, Any]:
     return {
         # PostgreSQL supports isoformatted timestamps
         "timestamp": timestamp.isoformat(),
-        "offset": ts_with_tz.offset,
-        "neg_utc_offset": ts_with_tz.negative_utc,
+        "offset": ts_with_tz.offset_minutes(),
+        "neg_utc_offset": ts_with_tz.offset_minutes() == 0
+        and ts_with_tz.offset_bytes.startswith(b"-"),
         "offset_bytes": ts_with_tz.offset_bytes,
     }
 
 
 def revision_to_db(revision: Revision) -> Dict[str, Any]:
-    """Convert a swh-model revision to its database representation.
-    """
+    """Convert a swh-model revision to its database representation."""
 
     author = author_to_db(revision.author)
     date = date_to_db(revision.date)
@@ -194,7 +187,11 @@ def revision_to_db(revision: Revision) -> Dict[str, Any]:
         "extra_headers": revision.extra_headers,
         "raw_manifest": revision.raw_manifest,
         "parents": [
-            {"id": revision.id, "parent_id": parent, "parent_rank": i,}
+            {
+                "id": revision.id,
+                "parent_id": parent,
+                "parent_rank": i,
+            }
             for i, parent in enumerate(revision.parents)
         ],
     }
@@ -216,8 +213,6 @@ def db_to_revision(db_revision: Dict[str, Any]) -> Optional[Revision]:
     )
     date = db_to_date(
         db_revision["date"],
-        db_revision["date_offset"],
-        db_revision["date_neg_utc_offset"],
         db_revision["date_offset_bytes"],
     )
 
@@ -228,13 +223,15 @@ def db_to_revision(db_revision: Dict[str, Any]) -> Optional[Revision]:
     )
     committer_date = db_to_date(
         db_revision["committer_date"],
-        db_revision["committer_date_offset"],
-        db_revision["committer_date_neg_utc_offset"],
         db_revision["committer_date_offset_bytes"],
     )
 
-    assert author, "author is None"
-    assert committer, "committer is None"
+    assert (author is None) == (
+        db_revision["author_fullname"] is None
+    ), "author is unexpectedly None"
+    assert (committer is None) == (
+        db_revision["committer_fullname"] is None
+    ), "committer is unexpectedly None"
 
     parents = []
     if "parents" in db_revision:
@@ -269,8 +266,7 @@ def db_to_revision(db_revision: Dict[str, Any]) -> Optional[Revision]:
 
 
 def release_to_db(release: Release) -> Dict[str, Any]:
-    """Convert a swh-model release to its database representation.
-    """
+    """Convert a swh-model release to its database representation."""
     author = author_to_db(release.author)
     date = date_to_db(release.date)
 
@@ -307,8 +303,6 @@ def db_to_release(db_release: Dict[str, Any]) -> Optional[Release]:
     )
     date = db_to_date(
         db_release["date"],
-        db_release["date_offset"],
-        db_release["date_neg_utc_offset"],
         db_release["date_offset_bytes"],
     )
 
@@ -340,7 +334,8 @@ def db_to_raw_extrinsic_metadata(row) -> RawExtrinsicMetadata:
             url=row["metadata_authority.url"],
         ),
         fetcher=MetadataFetcher(
-            name=row["metadata_fetcher.name"], version=row["metadata_fetcher.version"],
+            name=row["metadata_fetcher.name"],
+            version=row["metadata_fetcher.version"],
         ),
         discovery_date=row["discovery_date"],
         format=row["format"],
