@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,7 +6,6 @@
 import datetime
 import logging
 import random
-import select
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 
 from swh.core.db import BaseDb
@@ -26,11 +25,9 @@ def jsonize(d):
 
 
 class Db(BaseDb):
-    """Proxy to the SWH DB, with wrappers around stored procedures
+    """Proxy to the SWH DB, with wrappers around stored procedures"""
 
-    """
-
-    current_version = 180
+    current_version = 182
 
     def mktemp_dir_entry(self, entry_type, cur=None):
         self._cursor(cur).execute(
@@ -49,19 +46,6 @@ class Db(BaseDb):
     def mktemp_snapshot_branch(self, cur=None):
         pass
 
-    def register_listener(self, notify_queue, cur=None):
-        """Register a listener for NOTIFY queue `notify_queue`"""
-        self._cursor(cur).execute("LISTEN %s" % notify_queue)
-
-    def listen_notifies(self, timeout):
-        """Listen to notifications for `timeout` seconds"""
-        if select.select([self.conn], [], [], timeout) == ([], [], []):
-            return
-        else:
-            self.conn.poll()
-            while self.conn.notifies:
-                yield self.conn.notifies.pop(0)
-
     @stored_procedure("swh_content_add")
     def content_add_from_temp(self, cur=None):
         pass
@@ -125,13 +109,13 @@ class Db(BaseDb):
             inner join content on (content.{algo}=hash)
         """
         yield from execute_values_generator(
-            cur, query, ((hash_,) for hash_ in hashes),
+            cur,
+            query,
+            ((hash_,) for hash_ in hashes),
         )
 
     def content_get_range(self, start, end, limit=None, cur=None):
-        """Retrieve contents within range [start, end].
-
-        """
+        """Retrieve contents within range [start, end]."""
         cur = self._cursor(cur)
         query = """select %s from content
                    where %%s <= sha1 and sha1 <= %%s
@@ -243,7 +227,10 @@ class Db(BaseDb):
     snapshot_count_cols = ["target_type", "count"]
 
     def snapshot_count_branches(
-        self, snapshot_id, branch_name_exclude_prefix=None, cur=None,
+        self,
+        snapshot_id,
+        branch_name_exclude_prefix=None,
+        cur=None,
     ):
         cur = self._cursor(cur)
         query = """\
@@ -392,9 +379,7 @@ class Db(BaseDb):
         yield from cur
 
     def directory_entry_get_by_path(self, directory, paths, cur=None):
-        """Retrieve a directory entry by path.
-
-        """
+        """Retrieve a directory entry by path."""
         cur = self._cursor(cur)
 
         cols = ", ".join(self.directory_ls_cols)
@@ -415,6 +400,19 @@ class Db(BaseDb):
         )
         return list(cur)
 
+    def directory_get_raw_manifest(
+        self, directory_ids: List[Sha1Git], cur=None
+    ) -> Iterable[Tuple[Sha1Git, bytes]]:
+        cur = self._cursor(cur)
+        yield from execute_values_generator(
+            cur,
+            """
+            SELECT t.id, raw_manifest FROM (VALUES %s) as t(id)
+            INNER JOIN directory ON (t.id=directory.id)
+            """,
+            ((id_,) for id_ in directory_ids),
+        )
+
     def directory_get_random(self, cur=None):
         return self._get_random_row_from_table("directory", ["id"], "id", cur)
 
@@ -490,9 +488,7 @@ class Db(BaseDb):
     def origin_visit_status_add(
         self, visit_status: OriginVisitStatus, cur=None
     ) -> None:
-        """Add new origin visit status
-
-        """
+        """Add new origin visit status"""
         assert self.origin_visit_status_cols[0] == "origin"
         assert self.origin_visit_status_cols[-1] == "metadata"
         cols = self.origin_visit_status_cols[1:-1]
@@ -512,9 +508,7 @@ class Db(BaseDb):
     origin_visit_cols = ["origin", "visit", "date", "type"]
 
     def origin_visit_add_with_id(self, origin_visit: OriginVisit, cur=None) -> None:
-        """Insert origin visit when id are already set
-
-        """
+        """Insert origin visit when id are already set"""
         ov = origin_visit
         assert ov.visit is not None
         cur = self._cursor(cur)
@@ -558,9 +552,7 @@ class Db(BaseDb):
     def _make_origin_visit_status(
         self, row: Optional[Tuple[Any]]
     ) -> Optional[Dict[str, Any]]:
-        """Make an origin_visit_status dict out of a row
-
-        """
+        """Make an origin_visit_status dict out of a row"""
         if not row:
             return None
         return dict(zip(self.origin_visit_status_cols, row))
@@ -573,9 +565,7 @@ class Db(BaseDb):
         require_snapshot: bool = False,
         cur=None,
     ) -> Optional[Dict[str, Any]]:
-        """Given an origin visit id, return its latest origin_visit_status
-
-        """
+        """Given an origin visit id, return its latest origin_visit_status"""
         cur = self._cursor(cur)
 
         query_parts = [
@@ -611,9 +601,7 @@ class Db(BaseDb):
         limit: int,
         cur=None,
     ):
-        """Retrieve visit_status rows for visit (origin, visit) in a paginated way.
-
-        """
+        """Retrieve visit_status rows for visit (origin, visit) in a paginated way."""
         cur = self._cursor(cur)
 
         query_parts = [
@@ -644,7 +632,12 @@ class Db(BaseDb):
         yield from cur
 
     def origin_visit_get_range(
-        self, origin: str, visit_from: int, order: ListOrder, limit: int, cur=None,
+        self,
+        origin: str,
+        visit_from: int,
+        order: ListOrder,
+        limit: int,
+        cur=None,
     ):
         cur = self._cursor(cur)
 
@@ -653,7 +646,7 @@ class Db(BaseDb):
             f"SELECT {', '.join(origin_visit_cols)} FROM origin_visit ov ",
             "INNER JOIN origin o ON o.id = ov.origin ",
         ]
-        query_parts.append("WHERE o.url = %s")
+        query_parts.append("WHERE ov.origin = (select id from origin where url = %s)")
         query_params: List[Any] = [origin]
 
         if visit_from > 0:
@@ -673,6 +666,46 @@ class Db(BaseDb):
         cur.execute(query, tuple(query_params))
         yield from cur
 
+    def origin_visit_status_get_all_in_range(
+        self,
+        origin: str,
+        allowed_statuses: Optional[List[str]],
+        require_snapshot: bool,
+        visit_from: int,
+        visit_to: int,
+        cur=None,
+    ):
+        cur = self._cursor(cur)
+
+        query_parts = [
+            f"SELECT {', '.join(self.origin_visit_status_select_cols)}",
+            " FROM origin_visit_status ovs",
+            " INNER JOIN origin o ON o.id = ovs.origin",
+        ]
+        query_parts.append("WHERE ovs.origin = (select id from origin where url = %s)")
+        query_params: List[Any] = [origin]
+
+        assert visit_from <= visit_to
+
+        query_parts.append("AND ovs.visit >= %s")
+        query_params.append(visit_from)
+
+        query_parts.append("AND ovs.visit <= %s")
+        query_params.append(visit_to)
+
+        if require_snapshot:
+            query_parts.append("AND ovs.snapshot is not null")
+
+        if allowed_statuses:
+            query_parts.append("AND ovs.status IN %s")
+            query_params.append(tuple(allowed_statuses))
+
+        query_parts.append("ORDER BY ovs.visit ASC, ovs.date ASC")
+
+        query = "\n".join(query_parts)
+        cur.execute(query, tuple(query_params))
+        yield from cur
+
     def origin_visit_get(self, origin_id, visit_id, cur=None):
         """Retrieve information on visit visit_id of origin origin_id.
 
@@ -691,7 +724,7 @@ class Db(BaseDb):
             FROM origin_visit ov
             INNER JOIN origin o ON o.id = ov.origin
             INNER JOIN origin_visit_status ovs USING (origin, visit)
-            WHERE o.url = %%s AND ov.visit = %%s
+            WHERE ov.origin = (select id from origin where url = %%s) AND ov.visit = %%s
             ORDER BY ovs.date DESC
             LIMIT 1
             """ % (
@@ -754,7 +787,9 @@ class Db(BaseDb):
             "INNER JOIN origin o ON o.id = ov.origin",
             "INNER JOIN origin_visit_status ovs USING (origin, visit)",
         ]
-        query_parts.append("WHERE o.url = %s")
+        query_parts.append(
+            "WHERE ov.origin = (SELECT id FROM origin o WHERE o.url = %s)"
+        )
         query_params: List[Any] = [origin_id]
 
         if type is not None:
@@ -768,9 +803,7 @@ class Db(BaseDb):
             query_parts.append("AND ovs.status IN %s")
             query_params.append(tuple(allowed_statuses))
 
-        query_parts.append(
-            "ORDER BY ov.date DESC, ov.visit DESC, ovs.date DESC LIMIT 1"
-        )
+        query_parts.append("ORDER BY ov.visit DESC, ovs.date DESC LIMIT 1")
 
         query = "\n".join(query_parts)
 
@@ -782,7 +815,7 @@ class Db(BaseDb):
 
     def origin_visit_get_random(self, type, cur=None):
         """Randomly select one origin visit that was full and in the last 3
-           months
+        months
 
         """
         cur = self._cursor(cur)
@@ -801,7 +834,7 @@ class Db(BaseDb):
         return cur.fetchone()
 
     @staticmethod
-    def mangle_query_key(key, main_table):
+    def mangle_query_key(key, main_table, ignore_displayname=False):
         if key == "id":
             return "t.id"
         if key == "parents":
@@ -812,25 +845,45 @@ class Db(BaseDb):
             WHERE rh.id = t.id
             ORDER BY rh.parent_rank
             )"""
+
         if "_" not in key:
-            return "%s.%s" % (main_table, key)
+            return f"{main_table}.{key}"
 
         head, tail = key.split("_", 1)
-        if head in ("author", "committer") and tail in (
+        if head not in ("author", "committer") or tail not in (
             "name",
             "email",
             "id",
             "fullname",
         ):
-            return "%s.%s" % (head, tail)
+            return f"{main_table}.{key}"
 
-        return "%s.%s" % (main_table, key)
+        if ignore_displayname:
+            return f"{head}.{tail}"
+        else:
+            if tail == "id":
+                return f"{head}.{tail}"
+            elif tail in ("name", "email"):
+                # These fields get populated again from fullname by
+                # converters.db_to_author if they're None, so we can just NULLify them
+                # when displayname is set.
+                return (
+                    f"CASE"
+                    f" WHEN {head}.displayname IS NULL THEN {head}.{tail} "
+                    f" ELSE NULL "
+                    f"END AS {key}"
+                )
+            elif tail == "fullname":
+                return f"COALESCE({head}.displayname, {head}.fullname) AS {key}"
 
-    def revision_get_from_list(self, revisions, cur=None):
+        assert False, "All cases should have been handled here"
+
+    def revision_get_from_list(self, revisions, ignore_displayname=False, cur=None):
         cur = self._cursor(cur)
 
         query_keys = ", ".join(
-            self.mangle_query_key(k, "revision") for k in self.revision_get_cols
+            self.mangle_query_key(k, "revision", ignore_displayname)
+            for k in self.revision_get_cols
         )
 
         yield from execute_values_generator(
@@ -893,7 +946,11 @@ class Db(BaseDb):
         filter_query = ""
         if extid_version is not None and extid_type is not None:
             filter_query = cur.mogrify(
-                "WHERE extid_version=%s AND extid_type=%s", (extid_version, extid_type,)
+                "WHERE extid_version=%s AND extid_type=%s",
+                (
+                    extid_version,
+                    extid_type,
+                ),
             ).decode()
 
         sql = f"""
@@ -911,16 +968,20 @@ class Db(BaseDb):
             template=b"(%s,%s,%s::object_type)",
         )
 
-    def revision_log(self, root_revisions, limit=None, cur=None):
+    def revision_log(
+        self, root_revisions, ignore_displayname=False, limit=None, cur=None
+    ):
         cur = self._cursor(cur)
 
-        query = """SELECT %s
-                   FROM swh_revision_log(%%s, %%s)
-                """ % ", ".join(
+        query = """\
+        SELECT %s
+        FROM swh_revision_log(
+          "root_revisions" := %%s, num_revs := %%s, "ignore_displayname" := %%s
+        )""" % ", ".join(
             self.revision_get_cols
         )
 
-        cur.execute(query, (root_revisions, limit))
+        cur.execute(query, (root_revisions, limit, ignore_displayname))
         yield from cur
 
     revision_shortlog_cols = ["id", "parents"]
@@ -1224,10 +1285,11 @@ class Db(BaseDb):
         cur.execute(query)
         yield from map(lambda row: row[0], cur)
 
-    def release_get_from_list(self, releases, cur=None):
+    def release_get_from_list(self, releases, ignore_displayname=False, cur=None):
         cur = self._cursor(cur)
         query_keys = ", ".join(
-            self.mangle_query_key(k, "release") for k in self.release_get_cols
+            self.mangle_query_key(k, "release", ignore_displayname)
+            for k in self.release_get_cols
         )
 
         yield from execute_values_generator(
