@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -47,10 +47,10 @@ from swh.storage.exc import HashCollision, StorageArgumentException, StorageDBEr
 from swh.storage.interface import (
     VISIT_STATUSES,
     ListOrder,
+    OriginVisitWithStatuses,
     PagedResult,
     PartialBranches,
 )
-from swh.storage.metrics import process_metrics, send_metric, timed
 from swh.storage.objstorage import ObjStorage
 from swh.storage.utils import (
     extract_collision_hash,
@@ -101,19 +101,46 @@ def convert_validation_exceptions():
 
 
 class Storage:
-    """SWH storage proxy, encompassing DB and object storage
-
-    """
+    """SWH storage proxy, encompassing DB and object storage"""
 
     def __init__(
-        self, db, objstorage, min_pool_conns=1, max_pool_conns=10, journal_writer=None
+        self,
+        db,
+        objstorage,
+        min_pool_conns=1,
+        max_pool_conns=10,
+        journal_writer=None,
+        query_options=None,
     ):
-        """
+        """Instantiate a storage instance backed by a PostgreSQL database and an
+        objstorage.
+
+        When ``db`` is passed as a connection string, then this module automatically
+        manages a connection pool between ``min_pool_conns`` and ``max_pool_conns``.
+        When ``db`` is an explicit psycopg2 connection, then ``min_pool_conns`` and
+        ``max_pool_conns`` are ignored and the connection is used directly.
+
         Args:
-            db_conn: either a libpq connection string, or a psycopg2 connection
-            obj_root: path to the root of the object storage
+            db: either a libpq connection string, or a psycopg2 connection
+            objstorage: configuration for the backend :class:`ObjStorage`
+            min_pool_conns: min number of connections in the psycopg2 pool
+            max_pool_conns: max number of connections in the psycopg2 pool
+            journal_writer: configuration for the :class:`JournalWriter`
+            query_options: configuration for the sql connections; keys of the dict are
+               the method names decorated with :func:`db_transaction` or
+               :func:`db_transaction_generator` (eg. :func:`content_find`), and values
+               are dicts (config_name, config_value) used to configure the sql
+               connection for the method_name. For example, using::
+
+                  {"content_get": {"statement_timeout": 5000}}
+
+               will override the default statement timeout for the :func:`content_get`
+               endpoint from 500ms to 5000ms.
+
+               See :mod:`swh.core.db.common` for more details.
 
         """
+
         try:
             if isinstance(db, psycopg2.extensions.connection):
                 self._pool = None
@@ -128,9 +155,9 @@ class Storage:
                 self._db = None
         except psycopg2.OperationalError as e:
             raise StorageDBError(e)
-
         self.journal_writer = JournalWriter(journal_writer)
         self.objstorage = ObjStorage(objstorage)
+        self.query_options = query_options
 
     def get_db(self):
         if self._db:
@@ -160,7 +187,6 @@ class Storage:
             if db:
                 self.put_db(db)
 
-    @timed
     @db_transaction()
     def check_config(self, *, check_write: bool, db: Db, cur=None) -> bool:
 
@@ -179,9 +205,14 @@ class Storage:
         cur.execute("select has_table_privilege(current_user, 'content', %s)", (check,))
         return cur.fetchone()[0]
 
+    @db_transaction()
+    def get_current_version(self, *, db: Db, cur=None):
+        """Returns the current code (expected) version"""
+        return db.current_version
+
     def _content_unique_key(self, hash, db):
         """Given a hash (tuple or dict), return a unique key from the
-           aggregation of keys.
+        aggregation of keys.
 
         """
         keys = db.content_hash_keys
@@ -190,8 +221,7 @@ class Storage:
         return tuple([hash[k] for k in keys])
 
     def _content_add_metadata(self, db, cur, content):
-        """Add content to the postgresql database but not the object storage.
-        """
+        """Add content to the postgresql database but not the object storage."""
         # create temporary table for metadata injection
         db.mktemp("content", cur)
 
@@ -226,8 +256,6 @@ class Storage:
             else:
                 raise
 
-    @timed
-    @process_metrics
     def content_add(self, content: List[Content]) -> Dict[str, int]:
         ctime = now()
 
@@ -260,7 +288,6 @@ class Storage:
             "content:add:bytes": objstorage_summary["content:add:bytes"],
         }
 
-    @timed
     @db_transaction()
     def content_update(
         self, contents: List[Dict[str, Any]], keys: List[str] = [], *, db: Db, cur=None
@@ -275,14 +302,15 @@ class Storage:
             db.copy_to(contents, "tmp_content", select_keys, cur)
             db.content_update_from_temp(keys_to_update=keys, cur=cur)
 
-    @timed
-    @process_metrics
     @db_transaction()
     def content_add_metadata(
         self, content: List[Content], *, db: Db, cur=None
     ) -> Dict[str, int]:
         missing = self.content_missing(
-            (c.to_dict() for c in content), key_hash="sha1_git", db=db, cur=cur,
+            (c.to_dict() for c in content),
+            key_hash="sha1_git",
+            db=db,
+            cur=cur,
         )
         contents = [c for c in content if c.sha1_git in missing]
 
@@ -293,12 +321,10 @@ class Storage:
             "content:add": len(contents),
         }
 
-    @timed
     def content_get_data(self, content: Sha1) -> Optional[bytes]:
         # FIXME: Make this method support slicing the `data`
         return self.objstorage.content_get(content)
 
-    @timed
     @db_transaction()
     def content_get_partition(
         self,
@@ -334,7 +360,6 @@ class Storage:
         assert len(contents) <= limit
         return PagedResult(results=contents, next_page_token=next_page_token)
 
-    @timed
     @db_transaction(statement_timeout=500)
     def content_get(
         self, contents: List[bytes], algo: str = "sha1", *, db: Db, cur=None
@@ -355,7 +380,6 @@ class Storage:
 
         return [contents_by_hash.get(sha1) for sha1 in contents]
 
-    @timed
     @db_transaction_generator()
     def content_missing(
         self,
@@ -376,7 +400,6 @@ class Storage:
         for obj in db.content_missing_from_list(contents, cur):
             yield obj[key_hash_idx]
 
-    @timed
     @db_transaction_generator()
     def content_missing_per_sha1(
         self, contents: List[bytes], *, db: Db, cur=None
@@ -384,7 +407,6 @@ class Storage:
         for obj in db.content_missing_per_sha1(contents, cur):
             yield obj[0]
 
-    @timed
     @db_transaction_generator()
     def content_missing_per_sha1_git(
         self, contents: List[bytes], *, db: Db, cur=None
@@ -392,7 +414,6 @@ class Storage:
         for obj in db.content_missing_per_sha1_git(contents, cur):
             yield obj[0]
 
-    @timed
     @db_transaction()
     def content_find(
         self, content: Dict[str, Any], *, db: Db, cur=None
@@ -416,7 +437,6 @@ class Storage:
             contents.append(Content(**row_d))
         return contents
 
-    @timed
     @db_transaction()
     def content_get_random(self, *, db: Db, cur=None) -> Sha1Git:
         return db.content_get_random(cur)
@@ -450,8 +470,6 @@ class Storage:
         # move metadata in place
         db.skipped_content_add_from_temp(cur)
 
-    @timed
-    @process_metrics
     @db_transaction()
     def skipped_content_add(
         self, content: List[SkippedContent], *, db: Db, cur=None
@@ -460,7 +478,9 @@ class Storage:
         content = [attr.evolve(c, ctime=ctime) for c in content]
 
         missing_contents = self.skipped_content_missing(
-            (c.to_dict() for c in content), db=db, cur=cur,
+            (c.to_dict() for c in content),
+            db=db,
+            cur=cur,
         )
         content = [
             c
@@ -481,7 +501,6 @@ class Storage:
             "skipped_content:add": len(content),
         }
 
-    @timed
     @db_transaction_generator()
     def skipped_content_missing(
         self, contents: List[Dict[str, Any]], *, db: Db, cur=None
@@ -490,8 +509,6 @@ class Storage:
         for content in db.skipped_content_missing(contents, cur):
             yield dict(zip(db.content_hash_keys, content))
 
-    @timed
-    @process_metrics
     @db_transaction()
     def directory_add(
         self, directories: List[Directory], *, db: Db, cur=None
@@ -521,8 +538,12 @@ class Storage:
             dir_ for dir_ in directories if dir_.id in dirs_missing
         )
 
-        # Copy directory ids
-        dirs_missing_dict = ({"id": dir} for dir in dirs_missing)
+        # Copy directory metadata
+        dirs_missing_dict = (
+            {"id": dir_.id, "raw_manifest": dir_.raw_manifest}
+            for dir_ in directories
+            if dir_.id in dirs_missing
+        )
         db.mktemp("directory", cur)
         db.copy_to(dirs_missing_dict, "tmp_directory", ["id", "raw_manifest"], cur)
 
@@ -549,7 +570,6 @@ class Storage:
 
         return summary
 
-    @timed
     @db_transaction_generator()
     def directory_missing(
         self, directories: List[Sha1Git], *, db: Db, cur=None
@@ -557,7 +577,6 @@ class Storage:
         for obj in db.directory_missing_from_list(directories, cur):
             yield obj[0]
 
-    @timed
     @db_transaction_generator(statement_timeout=20000)
     def directory_ls(
         self, directory: Sha1Git, recursive: bool = False, *, db: Db, cur=None
@@ -570,15 +589,13 @@ class Storage:
         for line in res_gen:
             yield dict(zip(db.directory_ls_cols, line))
 
-    @timed
-    @db_transaction(statement_timeout=2000)
+    @db_transaction(statement_timeout=4000)
     def directory_entry_get_by_path(
         self, directory: Sha1Git, paths: List[bytes], *, db: Db, cur=None
     ) -> Optional[Dict[str, Any]]:
         res = db.directory_entry_get_by_path(directory, paths, cur)
         return dict(zip(db.directory_ls_cols, res)) if res else None
 
-    @timed
     @db_transaction()
     def directory_get_random(self, *, db: Db, cur=None) -> Sha1Git:
         return db.directory_get_random(cur)
@@ -609,8 +626,12 @@ class Storage:
             next_page_token=None,
         )
 
-    @timed
-    @process_metrics
+    @db_transaction()
+    def directory_get_raw_manifest(
+        self, directory_ids: List[Sha1Git], *, db: Db, cur=None
+    ) -> Dict[Sha1Git, Optional[bytes]]:
+        return dict(db.directory_get_raw_manifest(directory_ids, cur=cur))
+
     @db_transaction()
     def revision_add(
         self, revisions: List[Revision], *, db: Db, cur=None
@@ -658,7 +679,6 @@ class Storage:
 
         return {"revision:add": len(revisions_missing)}
 
-    @timed
     @db_transaction_generator()
     def revision_missing(
         self, revisions: List[Sha1Git], *, db: Db, cur=None
@@ -669,43 +689,51 @@ class Storage:
         for obj in db.revision_missing_from_list(revisions, cur):
             yield obj[0]
 
-    @timed
-    @db_transaction(statement_timeout=1000)
+    @db_transaction(statement_timeout=2000)
     def revision_get(
-        self, revision_ids: List[Sha1Git], *, db: Db, cur=None
+        self,
+        revision_ids: List[Sha1Git],
+        ignore_displayname: bool = False,
+        *,
+        db: Db,
+        cur=None,
     ) -> List[Optional[Revision]]:
         revisions = []
-        for line in db.revision_get_from_list(revision_ids, cur):
+        for line in db.revision_get_from_list(revision_ids, ignore_displayname, cur):
             revision = converters.db_to_revision(dict(zip(db.revision_get_cols, line)))
             revisions.append(revision)
 
         return revisions
 
-    @timed
     @db_transaction_generator(statement_timeout=2000)
     def revision_log(
-        self, revisions: List[Sha1Git], limit: Optional[int] = None, *, db: Db, cur=None
+        self,
+        revisions: List[Sha1Git],
+        ignore_displayname: bool = False,
+        limit: Optional[int] = None,
+        *,
+        db: Db,
+        cur=None,
     ) -> Iterable[Optional[Dict[str, Any]]]:
-        for line in db.revision_log(revisions, limit, cur):
+        for line in db.revision_log(
+            revisions, ignore_displayname=ignore_displayname, limit=limit, cur=cur
+        ):
             data = converters.db_to_revision(dict(zip(db.revision_get_cols, line)))
             if not data:
                 yield None
                 continue
             yield data.to_dict()
 
-    @timed
     @db_transaction_generator(statement_timeout=2000)
     def revision_shortlog(
         self, revisions: List[Sha1Git], limit: Optional[int] = None, *, db: Db, cur=None
     ) -> Iterable[Optional[Tuple[Sha1Git, Tuple[Sha1Git, ...]]]]:
         yield from db.revision_shortlog(revisions, limit, cur)
 
-    @timed
     @db_transaction()
     def revision_get_random(self, *, db: Db, cur=None) -> Sha1Git:
         return db.revision_get_random(cur)
 
-    @timed
     @db_transaction()
     def extid_get_from_extid(
         self,
@@ -722,7 +750,6 @@ class Storage:
                 extids.append(converters.db_to_extid(dict(zip(db.extid_cols, row))))
         return extids
 
-    @timed
     @db_transaction()
     def extid_get_from_target(
         self,
@@ -751,7 +778,6 @@ class Storage:
                 extids.append(converters.db_to_extid(dict(zip(db.extid_cols, row))))
         return extids
 
-    @timed
     @db_transaction()
     def extid_add(self, ids: List[ExtID], *, db: Db, cur=None) -> Dict[str, int]:
         extid = [
@@ -775,8 +801,6 @@ class Storage:
 
         return {"extid:add": len(extid)}
 
-    @timed
-    @process_metrics
     @db_transaction()
     def release_add(
         self, releases: List[Release], *, db: Db, cur=None
@@ -806,7 +830,6 @@ class Storage:
 
         return {"release:add": len(releases_missing)}
 
-    @timed
     @db_transaction_generator()
     def release_missing(
         self, releases: List[Sha1Git], *, db: Db, cur=None
@@ -817,24 +840,25 @@ class Storage:
         for obj in db.release_missing_from_list(releases, cur):
             yield obj[0]
 
-    @timed
-    @db_transaction(statement_timeout=500)
+    @db_transaction(statement_timeout=1000)
     def release_get(
-        self, releases: List[Sha1Git], *, db: Db, cur=None
+        self,
+        releases: List[Sha1Git],
+        ignore_displayname: bool = False,
+        *,
+        db: Db,
+        cur=None,
     ) -> List[Optional[Release]]:
         rels = []
-        for release in db.release_get_from_list(releases, cur):
+        for release in db.release_get_from_list(releases, ignore_displayname, cur):
             data = converters.db_to_release(dict(zip(db.release_get_cols, release)))
             rels.append(data if data else None)
         return rels
 
-    @timed
     @db_transaction()
     def release_get_random(self, *, db: Db, cur=None) -> Sha1Git:
         return db.release_get_random(cur)
 
-    @timed
-    @process_metrics
     @db_transaction()
     def snapshot_add(
         self, snapshots: List[Snapshot], *, db: Db, cur=None
@@ -872,7 +896,6 @@ class Storage:
 
         return {"snapshot:add": count}
 
-    @timed
     @db_transaction_generator()
     def snapshot_missing(
         self, snapshots: List[Sha1Git], *, db: Db, cur=None
@@ -880,7 +903,6 @@ class Storage:
         for obj in db.snapshot_missing_from_list(snapshots, cur):
             yield obj[0]
 
-    @timed
     @db_transaction(statement_timeout=2000)
     def snapshot_get(
         self, snapshot_id: Sha1Git, *, db: Db, cur=None
@@ -897,7 +919,6 @@ class Storage:
             "next_branch": d["next_branch"],
         }
 
-    @timed
     @db_transaction(statement_timeout=2000)
     def snapshot_count_branches(
         self,
@@ -911,12 +932,13 @@ class Storage:
             [
                 bc
                 for bc in db.snapshot_count_branches(
-                    snapshot_id, branch_name_exclude_prefix, cur,
+                    snapshot_id,
+                    branch_name_exclude_prefix,
+                    cur,
                 )
             ]
         )
 
-    @timed
     @db_transaction(statement_timeout=2000)
     def snapshot_get_branches(
         self,
@@ -932,7 +954,11 @@ class Storage:
     ) -> Optional[PartialBranches]:
 
         if snapshot_id == EMPTY_SNAPSHOT_ID:
-            return PartialBranches(id=snapshot_id, branches={}, next_branch=None,)
+            return PartialBranches(
+                id=snapshot_id,
+                branches={},
+                next_branch=None,
+            )
 
         if list(self.snapshot_missing([snapshot_id])):
             return None
@@ -974,15 +1000,15 @@ class Storage:
             )["name"]
 
         return PartialBranches(
-            id=snapshot_id, branches=branches, next_branch=next_branch,
+            id=snapshot_id,
+            branches=branches,
+            next_branch=next_branch,
         )
 
-    @timed
     @db_transaction()
     def snapshot_get_random(self, *, db: Db, cur=None) -> Sha1Git:
         return db.snapshot_get_random(cur)
 
-    @timed
     @db_transaction()
     def origin_visit_add(
         self, visits: List[OriginVisit], *, db: Db, cur=None
@@ -993,9 +1019,7 @@ class Storage:
                 raise StorageArgumentException("Unknown origin %s", visit.origin)
 
         all_visits = []
-        nb_visits = 0
         for visit in visits:
-            nb_visits += 1
             if not visit.visit:
                 with convert_validation_exceptions():
                     visit_id = db.origin_visit_add(
@@ -1018,7 +1042,6 @@ class Storage:
             )
             self._origin_visit_status_add(visit_status, db=db, cur=cur)
 
-        send_metric("origin_visit:add", count=nb_visits, method_name="origin_visit")
         return all_visits
 
     def _origin_visit_status_add(
@@ -1028,11 +1051,13 @@ class Storage:
         self.journal_writer.origin_visit_status_add([visit_status])
         db.origin_visit_status_add(visit_status, cur=cur)
 
-    @timed
-    @process_metrics
     @db_transaction()
     def origin_visit_status_add(
-        self, visit_statuses: List[OriginVisitStatus], *, db: Db, cur=None,
+        self,
+        visit_statuses: List[OriginVisitStatus],
+        *,
+        db: Db,
+        cur=None,
     ) -> Dict[str, int]:
         visit_statuses_ = []
 
@@ -1062,7 +1087,6 @@ class Storage:
             self._origin_visit_status_add(visit_status, db, cur)
         return {"origin_visit_status:add": len(visit_statuses_)}
 
-    @timed
     @db_transaction()
     def origin_visit_status_get_latest(
         self,
@@ -1087,7 +1111,6 @@ class Storage:
             return None
         return OriginVisitStatus(**row_d)
 
-    @timed
     @db_transaction(statement_timeout=500)
     def origin_visit_get(
         self,
@@ -1130,8 +1153,65 @@ class Storage:
 
         return PagedResult(results=visits, next_page_token=next_page_token)
 
-    @timed
     @db_transaction(statement_timeout=500)
+    def origin_visit_get_with_statuses(
+        self,
+        origin: str,
+        allowed_statuses: Optional[List[str]] = None,
+        require_snapshot: bool = False,
+        page_token: Optional[str] = None,
+        order: ListOrder = ListOrder.ASC,
+        limit: int = 10,
+        *,
+        db: Db,
+        cur=None,
+    ) -> PagedResult[OriginVisitWithStatuses]:
+        page_token = page_token or "0"
+        if not isinstance(order, ListOrder):
+            raise StorageArgumentException("order must be a ListOrder value")
+        if not isinstance(page_token, str):
+            raise StorageArgumentException("page_token must be a string.")
+
+        # First get visits (plus one so we can use it as the next page token if any)
+        visits_page = self.origin_visit_get(
+            origin=origin,
+            page_token=page_token,
+            order=order,
+            limit=limit,
+            db=db,
+            cur=cur,
+        )
+
+        visits = visits_page.results
+        next_page_token = visits_page.next_page_token
+
+        if visits:
+
+            visit_from = min(visits[0].visit, visits[-1].visit)
+            visit_to = max(visits[0].visit, visits[-1].visit)
+
+            # Then, fetch all statuses associated to these visits
+            visit_statuses: Dict[int, List[OriginVisitStatus]] = defaultdict(list)
+            for row in db.origin_visit_status_get_all_in_range(
+                origin,
+                allowed_statuses,
+                require_snapshot,
+                visit_from=visit_from,
+                visit_to=visit_to,
+                cur=cur,
+            ):
+                row_d = dict(zip(db.origin_visit_status_cols, row))
+
+                visit_statuses[row_d["visit"]].append(OriginVisitStatus(**row_d))
+
+        results = [
+            OriginVisitWithStatuses(visit=visit, statuses=visit_statuses[visit.visit])
+            for visit in visits
+        ]
+
+        return PagedResult(results=results, next_page_token=next_page_token)
+
+    @db_transaction(statement_timeout=1000)
     def origin_visit_find_by_date(
         self, origin: str, visit_date: datetime.datetime, *, db: Db, cur=None
     ) -> Optional[OriginVisit]:
@@ -1145,7 +1225,6 @@ class Storage:
             type=row_d["type"],
         )
 
-    @timed
     @db_transaction(statement_timeout=500)
     def origin_visit_get_by(
         self, origin: str, visit: int, *, db: Db, cur=None
@@ -1161,7 +1240,6 @@ class Storage:
             )
         return None
 
-    @timed
     @db_transaction(statement_timeout=4000)
     def origin_visit_get_latest(
         self,
@@ -1197,7 +1275,6 @@ class Storage:
             return visit
         return None
 
-    @timed
     @db_transaction(statement_timeout=500)
     def origin_visit_status_get(
         self,
@@ -1218,7 +1295,12 @@ class Storage:
         visit_statuses: List[OriginVisitStatus] = []
         # Take one more visit status so we can reuse it as the next page token if any
         for row in db.origin_visit_status_get_range(
-            origin, visit, date_from=date_from, order=order, limit=limit + 1, cur=cur,
+            origin,
+            visit,
+            date_from=date_from,
+            order=order,
+            limit=limit + 1,
+            cur=cur,
         ):
             row_d = dict(zip(db.origin_visit_status_cols, row))
             visit_statuses.append(OriginVisitStatus(**row_d))
@@ -1231,7 +1313,6 @@ class Storage:
 
         return PagedResult(results=visit_statuses, next_page_token=next_page_token)
 
-    @timed
     @db_transaction()
     def origin_visit_status_get_random(
         self, type: str, *, db: Db, cur=None
@@ -1242,7 +1323,6 @@ class Storage:
             return OriginVisitStatus(**row_d)
         return None
 
-    @timed
     @db_transaction(statement_timeout=2000)
     def object_find_by_sha1_git(
         self, ids: List[Sha1Git], *, db: Db, cur=None
@@ -1257,8 +1337,7 @@ class Storage:
 
         return ret
 
-    @timed
-    @db_transaction(statement_timeout=500)
+    @db_transaction(statement_timeout=1000)
     def origin_get(
         self, origins: List[str], *, db: Db, cur=None
     ) -> Iterable[Optional[Origin]]:
@@ -1270,8 +1349,7 @@ class Storage:
             result.append(None if url is None else Origin(url=url))
         return result
 
-    @timed
-    @db_transaction(statement_timeout=500)
+    @db_transaction(statement_timeout=1000)
     def origin_get_by_sha1(
         self, sha1s: List[bytes], *, db: Db, cur=None
     ) -> List[Optional[Dict[str, Any]]]:
@@ -1280,13 +1358,11 @@ class Storage:
             for row in db.origin_get_by_sha1(sha1s, cur)
         ]
 
-    @timed
     @db_transaction_generator()
     def origin_get_range(self, origin_from=1, origin_count=100, *, db: Db, cur=None):
         for origin in db.origin_get_range(origin_from, origin_count, cur):
             yield dict(zip(db.origin_get_range_cols, origin))
 
-    @timed
     @db_transaction()
     def origin_list(
         self, page_token: Optional[str] = None, limit: int = 100, *, db: Db, cur=None
@@ -1313,7 +1389,6 @@ class Storage:
         assert len(origins) <= limit
         return PagedResult(results=origins, next_page_token=next_page_token)
 
-    @timed
     @db_transaction()
     def origin_search(
         self,
@@ -1348,7 +1423,6 @@ class Storage:
 
         return PagedResult(results=origins, next_page_token=next_page_token)
 
-    @timed
     @db_transaction()
     def origin_count(
         self,
@@ -1361,15 +1435,12 @@ class Storage:
     ) -> int:
         return db.origin_count(url_pattern, regexp, with_visit, cur)
 
-    @timed
     @db_transaction()
     def origin_snapshot_get_all(
         self, origin_url: str, *, db: Db, cur=None
     ) -> List[Sha1Git]:
         return list(db.origin_snapshot_get_all(origin_url, cur))
 
-    @timed
-    @process_metrics
     @db_transaction()
     def origin_add(self, origins: List[Origin], *, db: Db, cur=None) -> Dict[str, int]:
         urls = [o.url for o in origins]
@@ -1410,11 +1481,12 @@ class Storage:
         for key in keys:
             cur.execute("select * from swh_update_counter(%s)", (key,))
 
-    @timed
-    @process_metrics
     @db_transaction()
     def raw_extrinsic_metadata_add(
-        self, metadata: List[RawExtrinsicMetadata], db, cur,
+        self,
+        metadata: List[RawExtrinsicMetadata],
+        db,
+        cur,
     ) -> Dict[str, int]:
         metadata = list(metadata)
         self.journal_writer.raw_extrinsic_metadata_add(metadata)
@@ -1471,10 +1543,18 @@ class Storage:
 
         authority_id = self._get_authority_id(authority, db, cur)
         if not authority_id:
-            return PagedResult(next_page_token=None, results=[],)
+            return PagedResult(
+                next_page_token=None,
+                results=[],
+            )
 
         rows = db.raw_extrinsic_metadata_get(
-            str(target), authority_id, after_time, after_fetcher, limit + 1, cur,
+            str(target),
+            authority_id,
+            after_time,
+            after_fetcher,
+            limit + 1,
+            cur,
         )
         rows = [dict(zip(db.raw_extrinsic_metadata_get_cols, row)) for row in rows]
         results = []
@@ -1497,11 +1577,18 @@ class Storage:
         else:
             next_page_token = None
 
-        return PagedResult(next_page_token=next_page_token, results=results,)
+        return PagedResult(
+            next_page_token=next_page_token,
+            results=results,
+        )
 
     @db_transaction()
     def raw_extrinsic_metadata_get_by_ids(
-        self, ids: List[Sha1Git], *, db: Db, cur=None,
+        self,
+        ids: List[Sha1Git],
+        *,
+        db: Db,
+        cur=None,
     ) -> List[RawExtrinsicMetadata]:
         return [
             converters.db_to_raw_extrinsic_metadata(
@@ -1512,7 +1599,11 @@ class Storage:
 
     @db_transaction()
     def raw_extrinsic_metadata_get_authorities(
-        self, target: ExtendedSWHID, *, db: Db, cur=None,
+        self,
+        target: ExtendedSWHID,
+        *,
+        db: Db,
+        cur=None,
     ) -> List[MetadataAuthority]:
         return [
             MetadataAuthority(
@@ -1524,8 +1615,6 @@ class Storage:
             ) in db.raw_extrinsic_metadata_get_authorities(str(target), cur)
         ]
 
-    @timed
-    @process_metrics
     @db_transaction()
     def metadata_fetcher_add(
         self, fetchers: List[MetadataFetcher], *, db: Db, cur=None
@@ -1538,7 +1627,6 @@ class Storage:
             count += 1
         return {"metadata_fetcher:add": count}
 
-    @timed
     @db_transaction(statement_timeout=500)
     def metadata_fetcher_get(
         self, name: str, version: str, *, db: Db, cur=None
@@ -1548,8 +1636,6 @@ class Storage:
             return None
         return MetadataFetcher.from_dict(dict(zip(db.metadata_fetcher_cols, row)))
 
-    @timed
-    @process_metrics
     @db_transaction()
     def metadata_authority_add(
         self, authorities: List[MetadataAuthority], *, db: Db, cur=None
@@ -1562,7 +1648,6 @@ class Storage:
             count += 1
         return {"metadata_authority:add": count}
 
-    @timed
     @db_transaction()
     def metadata_authority_get(
         self, type: MetadataAuthorityType, url: str, *, db: Db, cur=None
@@ -1573,9 +1658,7 @@ class Storage:
         return MetadataAuthority.from_dict(dict(zip(db.metadata_authority_cols, row)))
 
     def clear_buffers(self, object_types: Sequence[str] = ()) -> None:
-        """Do nothing
-
-        """
+        """Do nothing"""
         return None
 
     def flush(self, object_types: Sequence[str] = ()) -> Dict[str, int]:
