@@ -52,10 +52,13 @@ if pytest_cov is not None:
 
 @pytest.fixture
 def swh_storage_backend_config(swh_storage_backend_config):
-    """storage should test with its journal writer collaborator on
-
-    """
-    yield {**swh_storage_backend_config, "journal_writer": {"cls": "memory",}}
+    """storage should test with its journal writer collaborator on"""
+    yield {
+        **swh_storage_backend_config,
+        "journal_writer": {
+            "cls": "memory",
+        },
+    }
 
 
 @pytest.fixture
