@@ -34,9 +34,7 @@ TEST_CONFIG = {
 
 
 def test_config_ko_missing_mandatory_key():
-    """Missing configuration key will make the initialization fail
-
-    """
+    """Missing configuration key will make the initialization fail"""
     for key in TEST_CONFIG.keys():
         config = TEST_CONFIG.copy()
         config.pop(key)
@@ -51,9 +49,7 @@ def test_config_ko_missing_mandatory_key():
 
 
 def test_config_ko_unknown_object_type():
-    """Parse arguments will fail if the object type is unknown
-
-    """
+    """Parse arguments will fail if the object type is unknown"""
     backfiller = JournalBackfiller(TEST_CONFIG)
     with pytest.raises(ValueError) as e:
         backfiller.parse_arguments("unknown-object-type", 1, 2)
@@ -149,8 +145,6 @@ def test_compute_query_release():
     assert column_aliases == [
         "id",
         "date",
-        "date_offset",
-        "date_neg_utc_offset",
         "date_offset_bytes",
         "comment",
         "name",
@@ -167,7 +161,7 @@ def test_compute_query_release():
     assert (
         query
         == """
-select release.id as id,date,date_offset,date_neg_utc_offset,date_offset_bytes,comment,release.name as name,synthetic,target,target_type,a.id as author_id,a.name as author_name,a.email as author_email,a.fullname as author_fullname,raw_manifest
+select release.id as id,date,date_offset_bytes,comment,release.name as name,synthetic,target,target_type,a.id as author_id,a.name as author_name,a.email as author_email,a.fullname as author_fullname,raw_manifest
 from release
 left join person a on release.author=a.id
 where (release.id) >= %s and (release.id) < %s
@@ -179,7 +173,7 @@ where (release.id) >= %s and (release.id) < %s
 def test_byte_ranges(numbits):
     ranges = list(byte_ranges(numbits))
 
-    assert len(ranges) == 2 ** numbits
+    assert len(ranges) == 2**numbits
     assert ranges[0][0] is None
     assert ranges[-1][1] is None
 
