@@ -34,9 +34,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=1234567890, microseconds=0,),
-                offset=120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=1234567890,
+                    microseconds=0,
+                ),
                 offset_bytes=b"+0200",
             ),
             {
@@ -48,9 +49,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=1123456789, microseconds=0,),
-                offset=0,
-                negative_utc=True,
+                timestamp=Timestamp(
+                    seconds=1123456789,
+                    microseconds=0,
+                ),
                 offset_bytes=b"-0000",
             ),
             {
@@ -62,9 +64,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=1234567890, microseconds=0,),
-                offset=42,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=1234567890,
+                    microseconds=0,
+                ),
                 offset_bytes=b"+0042",
             ),
             {
@@ -76,9 +79,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=1634366813, microseconds=0,),
-                offset=-120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=1634366813,
+                    microseconds=0,
+                ),
                 offset_bytes=b"-0200",
             ),
             {
@@ -90,9 +94,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=0, microseconds=0,),
-                offset=-120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=0,
+                    microseconds=0,
+                ),
                 offset_bytes=b"-0200",
             ),
             {
@@ -104,9 +109,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=0, microseconds=1,),
-                offset=-120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=0,
+                    microseconds=1,
+                ),
                 offset_bytes=b"-0200",
             ),
             {
@@ -118,9 +124,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=-1, microseconds=0,),
-                offset=-120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=-1,
+                    microseconds=0,
+                ),
                 offset_bytes=b"-0200",
             ),
             {
@@ -132,9 +139,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=-1, microseconds=1,),
-                offset=-120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=-1,
+                    microseconds=1,
+                ),
                 offset_bytes=b"-0200",
             ),
             {
@@ -146,9 +154,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=-3600, microseconds=0,),
-                offset=-120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=-3600,
+                    microseconds=0,
+                ),
                 offset_bytes=b"-0200",
             ),
             {
@@ -160,9 +169,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=-3600, microseconds=1,),
-                offset=-120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=-3600,
+                    microseconds=1,
+                ),
                 offset_bytes=b"-0200",
             ),
             {
@@ -174,9 +184,10 @@ from swh.storage.postgresql import converters
         ),
         (
             TimestampWithTimezone(
-                timestamp=Timestamp(seconds=1234567890, microseconds=0,),
-                offset=120,
-                negative_utc=False,
+                timestamp=Timestamp(
+                    seconds=1234567890,
+                    microseconds=0,
+                ),
                 offset_bytes=b"+200",
             ),
             {
@@ -195,8 +206,6 @@ def test_date(model_date, db_date):
             date=None
             if db_date["timestamp"] is None
             else datetime.datetime.fromisoformat(db_date["timestamp"]),
-            offset=db_date["offset"],
-            neg_utc_offset=db_date["neg_utc_offset"],
             offset_bytes=db_date["offset_bytes"],
         )
         == model_date
@@ -205,10 +214,10 @@ def test_date(model_date, db_date):
 
 def test_db_to_author():
     # when
-    actual_author = converters.db_to_author(b"fullname", b"name", b"email")
+    actual_author = converters.db_to_author(b"name <email> ", b"name", b"email")
 
     # then
-    assert actual_author == Person(fullname=b"fullname", name=b"name", email=b"email",)
+    assert actual_author == Person.from_fullname(b"name <email> ")
 
 
 def test_db_to_author_none():
@@ -219,6 +228,11 @@ def test_db_to_author_none():
     assert actual_author is None
 
 
+def test_db_to_author_unparsed():
+    author = converters.db_to_author(b"Fullname <email@example.com>", None, None)
+    assert author == Person.from_fullname(b"Fullname <email@example.com>")
+
+
 def test_db_to_revision():
     # when
     actual_revision = converters.db_to_revision(
@@ -235,10 +249,10 @@ def test_db_to_revision():
             "type": "git",
             "directory": b"dir-sha1",
             "message": b"commit message",
-            "author_fullname": b"auth-fullname",
+            "author_fullname": b"auth-name <auth-email>",
             "author_name": b"auth-name",
             "author_email": b"auth-email",
-            "committer_fullname": b"comm-fullname",
+            "committer_fullname": b"comm-name <comm-email>",
             "committer_name": b"comm-name",
             "committer_email": b"comm-email",
             "metadata": {},
@@ -253,11 +267,15 @@ def test_db_to_revision():
     assert actual_revision == Revision(
         id=b"revision-id",
         author=Person(
-            fullname=b"auth-fullname", name=b"auth-name", email=b"auth-email",
+            fullname=b"auth-name <auth-email>",
+            name=b"auth-name",
+            email=b"auth-email",
         ),
         date=None,
         committer=Person(
-            fullname=b"comm-fullname", name=b"comm-name", email=b"comm-email",
+            fullname=b"comm-name <comm-email>",
+            name=b"comm-name",
+            email=b"comm-email",
         ),
         committer_date=None,
         type=RevisionType.GIT,
@@ -284,7 +302,7 @@ def test_db_to_release():
             "name": b"release-name",
             "comment": b"release comment",
             "synthetic": True,
-            "author_fullname": b"auth-fullname",
+            "author_fullname": b"auth-name <auth-email>",
             "author_name": b"auth-name",
             "author_email": b"auth-email",
             "raw_manifest": None,
@@ -294,7 +312,9 @@ def test_db_to_release():
     # then
     assert actual_release == Release(
         author=Person(
-            fullname=b"auth-fullname", name=b"auth-name", email=b"auth-email",
+            fullname=b"auth-name <auth-email>",
+            name=b"auth-name",
+            email=b"auth-email",
         ),
         date=None,
         id=b"release-id",
